@@ -33,6 +33,10 @@
 #include "../Utility/UI/jucer_ProjucerLookAndFeel.h"
 #include "../Licenses/jucer_LicenseController.h"
 
+#if JUCE_MODULE_AVAILABLE_juce_analytics
+ #include "jucer_ProjucerAnalytics.h"
+#endif
+
 struct ChildProcessCache;
 
 //==============================================================================
@@ -88,7 +92,8 @@ public:
 
     //==============================================================================
     void createNewProject();
-    void updateNewlyOpenedProject (Project&);
+    void createNewProjectFromClipboard();
+    void createNewPIP();
     void askUserToOpenFile();
     bool openFile (const File&);
     bool closeAllDocuments (bool askUserToSave);
@@ -106,9 +111,11 @@ public:
     void showApplicationUsageDataAgreementPopup();
     void dismissApplicationUsageDataAgreementPopup();
 
-    void showPathsWindow();
+    void showPathsWindow (bool highlightJUCEPath = false);
     void showEditorColourSchemeWindow();
 
+    void showPIPCreatorWindow();
+
     void launchForumBrowser();
     void launchModulesBrowser();
     void launchClassesBrowser();
@@ -128,32 +135,35 @@ public:
     static bool isEditorColourSchemeADefaultScheme (const StringArray& schemes, int editorColourSchemeIndex);
     static int getEditorColourSchemeForGUIColourScheme (const StringArray& schemes, int guiColourSchemeIndex);
 
+    //==============================================================================
+    void setAnalyticsEnabled (bool);
+
     //==============================================================================
     ProjucerLookAndFeel lookAndFeel;
 
-    ScopedPointer<StoredSettings> settings;
-    ScopedPointer<Icons> icons;
+    std::unique_ptr<StoredSettings> settings;
+    std::unique_ptr<Icons> icons;
 
     struct MainMenuModel;
-    ScopedPointer<MainMenuModel> menuModel;
+    std::unique_ptr<MainMenuModel> menuModel;
 
     MainWindowList mainWindowList;
     OpenDocumentManager openDocumentManager;
-    ScopedPointer<ApplicationCommandManager> commandManager;
+    std::unique_ptr<ApplicationCommandManager> commandManager;
 
-    ScopedPointer<Component> utf8Window, svgPathWindow, aboutWindow, applicationUsageDataWindow,
-                             pathsWindow, editorColourSchemeWindow;
+    std::unique_ptr<Component> utf8Window, svgPathWindow, aboutWindow, applicationUsageDataWindow,
+                             pathsWindow, editorColourSchemeWindow, pipCreatorWindow;
 
-    ScopedPointer<FileLogger> logger;
+    std::unique_ptr<FileLogger> logger;
 
     bool isRunningCommandLine;
-    ScopedPointer<ChildProcessCache> childProcessCache;
-    ScopedPointer<LicenseController> licenseController;
+    std::unique_ptr<ChildProcessCache> childProcessCache;
+    std::unique_ptr<LicenseController> licenseController;
 
 private:
     void* server = nullptr;
 
-    ScopedPointer<LatestVersionChecker> versionChecker;
+    std::unique_ptr<LatestVersionChecker> versionChecker;
     TooltipWindow tooltipWindow;
 
     void loginOrLogout();
@@ -166,6 +176,33 @@ private:
     void handleAsyncUpdate() override;
     void initCommandManager();
 
+    void deleteTemporaryFiles() const noexcept;
+
+    void createExamplesPopupMenu (PopupMenu&) noexcept;
+    Array<File> getSortedExampleDirectories() noexcept;
+    Array<File> getSortedExampleFilesInDirectory (const File&) const noexcept;
+
+    bool findWindowAndOpenPIP (const File&);
+
+    File getJUCEExamplesDirectoryPathFromGlobal() noexcept;
+    void findAndLaunchExample (int);
+    File findDemoRunnerExecutable() noexcept;
+    File findDemoRunnerProject() noexcept;
+    void launchDemoRunner();
+
+    int numExamples = 0;
+    std::unique_ptr<AlertWindow> demoRunnerAlert;
+
+   #if JUCE_LINUX
+    ChildProcess makeProcess;
+   #endif
+
+    void resetAnalytics() noexcept;
+    void setupAnalytics();
+
+    void showSetJUCEPathAlert();
+    std::unique_ptr<AlertWindow> pathAlert;
+
     //==============================================================================
     void setColourScheme (int index, bool saveSetting);
 
