@@ -28,13 +28,9 @@
 #include "jucer_Module.h"
 #include "../ProjectSaving/jucer_ProjectSaver.h"
 #include "../ProjectSaving/jucer_ProjectExport_Xcode.h"
+#include "../Application/jucer_ProjucerAnalytics.h"
 
 //==============================================================================
-static String trimCommentCharsFromStartOfLine (const String& line)
-{
-    return line.trimStart().trimCharactersAtStart ("*/").trimStart();
-}
-
 static var parseModuleDesc (const StringArray& lines)
 {
     DynamicObject* o = new DynamicObject();
@@ -470,7 +466,7 @@ void LibraryModule::getConfigFlags (Project& project, OwnedArray<Project::Config
 
         if (line.startsWith ("/**") && line.containsIgnoreCase ("Config:"))
         {
-            ScopedPointer<Project::ConfigFlag> config (new Project::ConfigFlag());
+            std::unique_ptr<Project::ConfigFlag> config (new Project::ConfigFlag());
             config->sourceModuleID = getID();
             config->symbol = line.fromFirstOccurrenceOf (":", false, false).trim();
 
@@ -735,7 +731,7 @@ File EnabledModuleList::getModuleFolder (const String& moduleID)
 {
     if (shouldUseGlobalPath (moduleID))
     {
-        if (isJuceModule (moduleID))
+        if (isJUCEModule (moduleID))
             return getModuleFolderFromPathIfItExists (getAppSettings().getStoredPath (Ids::defaultJuceModulePath).toString(), moduleID, project);
 
         return findUserModuleFolder (getAppSettings().getStoredPath (Ids::defaultUserModulePath).toString(), moduleID);
@@ -779,7 +775,7 @@ Value EnabledModuleList::shouldCopyModuleFilesLocally (const String& moduleID) c
                 .getPropertyAsValue (Ids::useLocalCopy, getUndoManager());
 }
 
-void EnabledModuleList::addModule (const File& moduleFolder, bool copyLocally, bool useGlobalPath)
+void EnabledModuleList::addModule (const File& moduleFolder, bool copyLocally, bool useGlobalPath, bool sendAnalyticsEvent)
 {
     ModuleDescription info (moduleFolder);
 
@@ -804,6 +800,14 @@ void EnabledModuleList::addModule (const File& moduleFolder, bool copyLocally, b
 
             for (Project::ExporterIterator exporter (project); exporter.next();)
                 exporter->getPathForModuleValue (moduleID) = path.toUnixStyle();
+
+            if (sendAnalyticsEvent)
+            {
+                StringPairArray data;
+                data.set ("label", moduleID);
+
+                Analytics::getInstance()->logEvent ("Module Added", data, ProjucerAnalyticsEvent::projectEvent);
+            }
         }
     }
 }
@@ -940,36 +944,6 @@ File EnabledModuleList::findDefaultModulesFolder (Project& project)
     return File::getCurrentWorkingDirectory();
 }
 
-bool EnabledModuleList::isJuceModule (const String& moduleID)
-{
-    static StringArray juceModuleIds =
-    {
-        "juce_analytics",
-        "juce_audio_basics",
-        "juce_audio_devices",
-        "juce_audio_formats",
-        "juce_audio_plugin_client",
-        "juce_audio_processors",
-        "juce_audio_utils",
-        "juce_blocks_basics",
-        "juce_box2d",
-        "juce_core",
-        "juce_cryptography",
-        "juce_data_structures",
-        "juce_dsp",
-        "juce_events",
-        "juce_graphics",
-        "juce_gui_basics",
-        "juce_gui_extra",
-        "juce_opengl",
-        "juce_osc",
-        "juce_product_unlocking",
-        "juce_video"
-    };
-
-    return juceModuleIds.contains (moduleID);
-}
-
 void EnabledModuleList::addModuleFromUserSelectedFile()
 {
     static auto lastLocation = findDefaultModulesFolder (project);
@@ -990,20 +964,20 @@ void EnabledModuleList::addModuleInteractive (const String& moduleID)
     list.scanGlobalJuceModulePath();
     if (auto* info = list.getModuleWithID (moduleID))
     {
-        addModule (info->moduleFolder, areMostModulesCopiedLocally(), areMostModulesUsingGlobalPath());
+        addModule (info->moduleFolder, areMostModulesCopiedLocally(), areMostModulesUsingGlobalPath(), true);
         return;
     }
 
     list.scanGlobalUserModulePath();
     if (auto* info = list.getModuleWithID (moduleID))
     {
-        addModule (info->moduleFolder, areMostModulesCopiedLocally(), areMostModulesUsingGlobalPath());
+        addModule (info->moduleFolder, areMostModulesCopiedLocally(), areMostModulesUsingGlobalPath(), true);
         return;
     }
 
     list.scanProjectExporterModulePaths (project);
     if (auto* info = list.getModuleWithID (moduleID))
-        addModule (info->moduleFolder, areMostModulesCopiedLocally(), false);
+        addModule (info->moduleFolder, areMostModulesCopiedLocally(), false, true);
     else
         addModuleFromUserSelectedFile();
 }
@@ -1026,16 +1000,17 @@ void EnabledModuleList::addModuleOfferingToCopy (const File& f, bool isFromUserS
         return;
     }
 
-    addModule (m.moduleFolder, areMostModulesCopiedLocally(), isFromUserSpecifiedFolder ? false
-                                                                                        : areMostModulesUsingGlobalPath());
+    addModule (m.moduleFolder, areMostModulesCopiedLocally(),
+               isFromUserSpecifiedFolder ? false : areMostModulesUsingGlobalPath(),
+               true);
 }
 
-bool isJuceFolder (const File& f)
+bool isJUCEFolder (const File& f)
 {
-    return isJuceModulesFolder (f.getChildFile ("modules"));
+    return isJUCEModulesFolder (f.getChildFile ("modules"));
 }
 
-bool isJuceModulesFolder (const File& f)
+bool isJUCEModulesFolder (const File& f)
 {
     return f.isDirectory() && f.getChildFile ("juce_core").isDirectory();
 }
