@@ -31,8 +31,8 @@ class ProjectExporter;
 class ProjectSaver;
 
 //==============================================================================
-bool isJuceModulesFolder (const File&);
-bool isJuceFolder (const File&);
+bool isJUCEModulesFolder (const File&);
+bool isJUCEFolder (const File&);
 
 //==============================================================================
 struct ModuleDescription
@@ -140,7 +140,6 @@ public:
 
     static File findGlobalModulesFolder();
     static File findDefaultModulesFolder (Project&);
-    static bool isJuceModule (const String& moduleID);
 
     bool isModuleEnabled (const String& moduleID) const;
 
@@ -156,7 +155,7 @@ public:
     ModuleDescription getModuleInfo (const String& moduleID);
     File getModuleFolder (const String& moduleID);
 
-    void addModule (const File& moduleManifestFile, bool copyLocally, bool useGlobalPath);
+    void addModule (const File& moduleManifestFile, bool copyLocally, bool useGlobalPath, bool sendAnalyticsEvent);
     void addModuleInteractive (const String& moduleID);
     void addModuleFromUserSelectedFile();
     void addModuleOfferingToCopy (const File&, bool isFromUserSpecifiedFolder);
