@@ -31,6 +31,8 @@
 class ProjectExporter;
 class LibraryModule;
 class EnabledModuleList;
+class ProjectContentComponent;
+class CompileEngineSettings;
 
 //==============================================================================
 class Project  : public FileBasedDocument,
@@ -114,7 +116,7 @@ public:
     StringPairArray getPreprocessorDefs() const          { return parsedPreprocessorDefs; }
 
     int getMaxBinaryFileSize() const                     { return maxBinaryFileSizeValue.get(); }
-    bool shouldIncludeBinaryInAppConfig() const          { return includeBinaryDataInAppConfigValue.get(); }
+    bool shouldIncludeBinaryInJuceHeader() const         { return includeBinaryDataInJuceHeaderValue.get(); }
     String getBinaryDataNamespaceString() const          { return binaryDataNamespaceValue.get(); }
 
     bool shouldDisplaySplashScreen() const               { return displaySplashScreenValue.get(); }
@@ -123,16 +125,6 @@ public:
 
     String getCppStandardString() const                  { return cppStandardValue.get(); }
 
-    //==============================================================================
-    bool shouldBuildVST() const                 { return buildVSTValue.get(); }
-    bool shouldBuildVST3() const                { return buildVST3Value.get(); }
-    bool shouldBuildAU() const                  { return buildAUValue.get(); }
-    bool shouldBuildAUv3() const                { return buildAUv3Value.get(); }
-    bool shouldBuildRTAS() const                { return buildRTASValue.get(); }
-    bool shouldBuildAAX() const                 { return buildAAXValue.get(); }
-    bool shouldBuildStandalonePlugin() const    { return buildStandaloneValue.get(); }
-    bool shouldEnableIAA() const                { return enableIAAValue.get(); }
-
     //==============================================================================
     String getPluginNameString() const                { return pluginNameValue.get(); }
     String getPluginDescriptionString() const         { return pluginDescriptionValue.get();}
@@ -140,29 +132,74 @@ public:
     String getPluginManufacturerCodeString() const    { return pluginManufacturerCodeValue.get(); }
     String getPluginCodeString() const                { return pluginCodeValue.get(); }
     String getPluginChannelConfigsString() const      { return pluginChannelConfigsValue.get(); }
+    String getAAXIdentifierString() const             { return pluginAAXIdentifierValue.get(); }
     String getPluginAUExportPrefixString() const      { return pluginAUExportPrefixValue.get(); }
     String getPluginAUMainTypeString() const          { return pluginAUMainTypeValue.get(); }
-    String getPluginRTASCategoryString() const        { return pluginRTASCategoryValue.get(); }
-    String getAAXIdentifierString() const             { return pluginAAXIdentifierValue.get(); }
-    String getPluginAAXCategoryString() const         { return pluginAAXCategoryValue.get(); }
 
-    bool isPluginSynth() const                        { return pluginIsSynthValue.get(); }
-    bool pluginWantsMidiInput() const                 { return pluginWantsMidiInputValue.get(); }
-    bool pluginProducesMidiOutput() const             { return pluginProducesMidiOutValue.get(); }
-    bool isPluginMidiEffect() const                   { return pluginIsMidiEffectPluginValue.get(); }
-    bool pluginEditorNeedsKeyFocus() const            { return pluginEditorNeedsKeyFocusValue.get(); }
-    bool isPluginRTASBypassDisabled() const           { return pluginRTASBypassDisabledValue.get(); }
-    bool isPluginRTASMultiMonoDisabled() const        { return pluginRTASMultiMonoDisabledValue.get(); }
-    bool isPluginAAXBypassDisabled() const            { return pluginAAXBypassDisabledValue.get(); }
-    bool isPluginAAXMultiMonoDisabled() const         { return pluginAAXMultiMonoDisabledValue.get(); }
+    //==============================================================================
+    static bool checkMultiChoiceVar (const ValueWithDefault& valueToCheck, Identifier idToCheck) noexcept
+    {
+        if (! valueToCheck.get().isArray())
+            return false;
+
+        auto v = valueToCheck.get();
+
+        if (auto* varArray = v.getArray())
+            return varArray->contains (idToCheck.toString());
+
+        return false;
+    }
+
+    //==============================================================================
+    bool shouldBuildVST() const                       { return checkMultiChoiceVar (pluginFormatsValue, Ids::buildVST); }
+    bool shouldBuildVST3() const                      { return checkMultiChoiceVar (pluginFormatsValue, Ids::buildVST3); }
+    bool shouldBuildAU() const                        { return checkMultiChoiceVar (pluginFormatsValue, Ids::buildAU); }
+    bool shouldBuildAUv3() const                      { return checkMultiChoiceVar (pluginFormatsValue, Ids::buildAUv3); }
+    bool shouldBuildRTAS() const                      { return checkMultiChoiceVar (pluginFormatsValue, Ids::buildRTAS); }
+    bool shouldBuildAAX() const                       { return checkMultiChoiceVar (pluginFormatsValue, Ids::buildAAX); }
+    bool shouldBuildStandalonePlugin() const          { return checkMultiChoiceVar (pluginFormatsValue, Ids::buildStandalone); }
+    bool shouldEnableIAA() const                      { return checkMultiChoiceVar (pluginFormatsValue, Ids::enableIAA); }
+
+    //==============================================================================
+    bool isPluginSynth() const                        { return checkMultiChoiceVar (pluginCharacteristicsValue, Ids::pluginIsSynth); }
+    bool pluginWantsMidiInput() const                 { return checkMultiChoiceVar (pluginCharacteristicsValue, Ids::pluginWantsMidiIn); }
+    bool pluginProducesMidiOutput() const             { return checkMultiChoiceVar (pluginCharacteristicsValue, Ids::pluginProducesMidiOut); }
+    bool isPluginMidiEffect() const                   { return checkMultiChoiceVar (pluginCharacteristicsValue, Ids::pluginIsMidiEffectPlugin); }
+    bool pluginEditorNeedsKeyFocus() const            { return checkMultiChoiceVar (pluginCharacteristicsValue, Ids::pluginEditorRequiresKeys); }
+    bool isPluginRTASBypassDisabled() const           { return checkMultiChoiceVar (pluginCharacteristicsValue, Ids::pluginRTASDisableBypass); }
+    bool isPluginRTASMultiMonoDisabled() const        { return checkMultiChoiceVar (pluginCharacteristicsValue, Ids::pluginRTASDisableMultiMono); }
+    bool isPluginAAXBypassDisabled() const            { return checkMultiChoiceVar (pluginCharacteristicsValue, Ids::pluginAAXDisableBypass); }
+    bool isPluginAAXMultiMonoDisabled() const         { return checkMultiChoiceVar (pluginCharacteristicsValue, Ids::pluginAAXDisableMultiMono); }
+
+    //==============================================================================
+    static StringArray getAllAUMainTypeStrings() noexcept;
+    static Array<var> getAllAUMainTypeVars() noexcept;
+    Array<var> getDefaultAUMainTypes() const noexcept;
+
+    static StringArray getAllVSTCategoryStrings() noexcept;
+    Array<var> getDefaultVSTCategories() const noexcept;
+
+    static StringArray getAllVST3CategoryStrings() noexcept;
+    Array<var> getDefaultVST3Categories() const noexcept;
+
+    static StringArray getAllAAXCategoryStrings() noexcept;
+    static Array<var> getAllAAXCategoryVars() noexcept;
+    Array<var> getDefaultAAXCategories() const noexcept;
+
+    static StringArray getAllRTASCategoryStrings() noexcept;
+    static Array<var> getAllRTASCategoryVars() noexcept;
+    Array<var> getDefaultRTASCategories() const noexcept;
+
+    String getAUMainTypeString() const noexcept;
+    String getVSTCategoryString() const noexcept;
+    String getVST3CategoryString() const noexcept;
+    int getAAXCategory() const noexcept;
+    int getRTASCategory() const noexcept;
 
-    String getPluginRTASCategoryCode();
-    String getAUMainTypeString();
-    String getAUMainTypeCode();
     String getIAATypeCode();
     String getIAAPluginName();
-    String getPluginVSTCategoryString();
 
+    //==============================================================================
     bool isAUPluginHost();
     bool isVSTPluginHost();
     bool isVST3PluginHost();
@@ -282,7 +319,7 @@ public:
         ProjectExporter& operator*() const       { return *exporter; }
         ProjectExporter* operator->() const      { return exporter.get(); }
 
-        ScopedPointer<ProjectExporter> exporter;
+        std::unique_ptr<ProjectExporter> exporter;
         int index;
 
     private:
@@ -331,27 +368,66 @@ public:
     String getUniqueTargetFolderSuffixForExporter (const String& exporterName, const String& baseTargetFolder);
 
     //==============================================================================
-    bool isCurrentlySaving() const noexcept     { return isSaving; }
+    bool isCurrentlySaving() const noexcept        { return isSaving; }
     bool shouldWaitAfterSaving = false;
     String specifiedExporterToSave = {};
 
+    //==============================================================================
+    bool isTemporaryProject() const noexcept             { return tempDirectory != File(); }
+    File getTemporaryDirectory() const noexcept          { return tempDirectory; }
+    void setTemporaryDirectory (const File&) noexcept;
+
+    void setOpenInIDEAfterSaving (bool open) noexcept    { openInIDEAfterSaving = open; }
+    bool shouldOpenInIDEAfterSaving() const noexcept     { return openInIDEAfterSaving; }
+
+    //==============================================================================
+    bool shouldSendGUIBuilderAnalyticsEvent() noexcept;
+
+    //==============================================================================
+    CompileEngineSettings& getCompileEngineSettings()    { return *compileEngineSettings; }
+
 private:
     ValueTree projectRoot  { Ids::JUCERPROJECT };
 
     ValueWithDefault projectNameValue, projectUIDValue, projectTypeValue, versionValue, bundleIdentifierValue, companyNameValue, companyCopyrightValue,
                      companyWebsiteValue, companyEmailValue, displaySplashScreenValue, reportAppUsageValue, splashScreenColourValue, cppStandardValue,
-                     headerSearchPathsValue, preprocessorDefsValue, userNotesValue, maxBinaryFileSizeValue, includeBinaryDataInAppConfigValue, binaryDataNamespaceValue;
+                     headerSearchPathsValue, preprocessorDefsValue, userNotesValue, maxBinaryFileSizeValue, includeBinaryDataInJuceHeaderValue, binaryDataNamespaceValue;
 
-    ValueWithDefault buildVSTValue, buildVST3Value, buildAUValue, buildAUv3Value, buildRTASValue, buildAAXValue, buildStandaloneValue,
-                     enableIAAValue, pluginNameValue, pluginDescriptionValue, pluginManufacturerValue, pluginManufacturerCodeValue,
-                     pluginCodeValue, pluginChannelConfigsValue, pluginIsSynthValue, pluginWantsMidiInputValue, pluginProducesMidiOutValue,
-                     pluginIsMidiEffectPluginValue, pluginEditorNeedsKeyFocusValue, pluginVSTCategoryValue, pluginAUExportPrefixValue,
-                     pluginAUMainTypeValue, pluginRTASCategoryValue, pluginRTASBypassDisabledValue, pluginRTASMultiMonoDisabledValue,
-                     pluginAAXIdentifierValue, pluginAAXCategoryValue, pluginAAXBypassDisabledValue, pluginAAXMultiMonoDisabledValue;
+    ValueWithDefault pluginFormatsValue, pluginNameValue, pluginDescriptionValue, pluginManufacturerValue, pluginManufacturerCodeValue,
+                     pluginCodeValue, pluginChannelConfigsValue, pluginCharacteristicsValue, pluginAUExportPrefixValue, pluginAAXIdentifierValue,
+                     pluginAUMainTypeValue, pluginRTASCategoryValue, pluginVSTCategoryValue, pluginVST3CategoryValue, pluginAAXCategoryValue;
+
+    //==============================================================================
+    std::unique_ptr<CompileEngineSettings> compileEngineSettings;
+
+    //==============================================================================
+    bool shouldWriteLegacyPluginFormatSettings = false;
+    bool shouldWriteLegacyPluginCharacteristicsSettings = false;
+
+    static Array<Identifier> getLegacyPluginFormatIdentifiers() noexcept;
+    static Array<Identifier> getLegacyPluginCharacteristicsIdentifiers() noexcept;
+
+    void writeLegacyPluginFormatSettings();
+    void writeLegacyPluginCharacteristicsSettings();
+
+    void coalescePluginFormatValues();
+    void coalescePluginCharacteristicsValues();
+    void updatePluginCategories();
+
+    //==============================================================================
+    File tempDirectory = {};
+    bool openInIDEAfterSaving = false;
+
+    void askUserWhereToSaveProject();
+    void moveTemporaryDirectory (const File&);
+    bool saveProjectRootToFile();
+
+    //==============================================================================
+    bool hasSentGUIBuilderAnalyticsEvent = false;
 
     //==============================================================================
     friend class Item;
-    ScopedPointer<EnabledModuleList> enabledModulesList;
+    std::unique_ptr<EnabledModuleList> enabledModulesList;
     bool isSaving = false;
     Time modificationTime;
     StringPairArray parsedPreprocessorDefs;
@@ -366,6 +442,7 @@ private:
     void createAudioPluginPropertyEditors (PropertyListBuilder& props);
 
     //==============================================================================
+    void updateTitle();
     void updateProjectSettings();
     ValueTree getConfigurations() const;
     ValueTree getConfigNode();
