@@ -100,10 +100,10 @@ public:
     }
 
     //==============================================================================
-    ValueWithDefault androidRepositories, androidDependencies, androidScreenOrientation, androidActivityClass,
-                     androidActivitySubClassName, androidManifestCustomXmlElements, androidVersionCode,
+    ValueWithDefault androidJavaLibs, androidRepositories, androidDependencies, androidScreenOrientation, androidActivityClass,
+                     androidActivitySubClassName, androidActivityBaseClassName, androidManifestCustomXmlElements, androidVersionCode,
                      androidMinimumSDK, androidTheme, androidSharedLibraries, androidStaticLibraries, androidExtraAssetsFolder,
-                     androidInternetNeeded, androidMicNeeded, androidBluetoothNeeded, androidExternalReadPermission,
+                     androidOboeRepositoryPath, androidInternetNeeded, androidMicNeeded, androidCameraNeeded, androidBluetoothNeeded, androidExternalReadPermission,
                      androidExternalWritePermission, androidInAppBillingPermission, androidVibratePermission,androidOtherPermissions,
                      androidEnableRemoteNotifications, androidRemoteNotificationsConfigFile, androidEnableContentSharing, androidKeyStore,
                      androidKeyStorePass, androidKeyAlias, androidKeyAliasPass, gradleVersion, gradleToolchain, androidPluginVersion, buildToolsVersion;
@@ -111,11 +111,13 @@ public:
     //==============================================================================
     AndroidProjectExporter (Project& p, const ValueTree& t)
         : ProjectExporter (p, t),
+          androidJavaLibs                      (settings, Ids::androidJavaLibs,                      getUndoManager()),
           androidRepositories                  (settings, Ids::androidRepositories,                  getUndoManager()),
           androidDependencies                  (settings, Ids::androidDependencies,                  getUndoManager()),
           androidScreenOrientation             (settings, Ids::androidScreenOrientation,             getUndoManager(), "unspecified"),
           androidActivityClass                 (settings, Ids::androidActivityClass,                 getUndoManager(), createDefaultClassName()),
           androidActivitySubClassName          (settings, Ids::androidActivitySubClassName,          getUndoManager()),
+          androidActivityBaseClassName         (settings, Ids::androidActivityBaseClassName,         getUndoManager(), "Activity"),
           androidManifestCustomXmlElements     (settings, Ids::androidManifestCustomXmlElements,     getUndoManager()),
           androidVersionCode                   (settings, Ids::androidVersionCode,                   getUndoManager(), "1"),
           androidMinimumSDK                    (settings, Ids::androidMinimumSDK,                    getUndoManager(), "10"),
@@ -123,8 +125,10 @@ public:
           androidSharedLibraries               (settings, Ids::androidSharedLibraries,               getUndoManager()),
           androidStaticLibraries               (settings, Ids::androidStaticLibraries,               getUndoManager()),
           androidExtraAssetsFolder             (settings, Ids::androidExtraAssetsFolder,             getUndoManager()),
+          androidOboeRepositoryPath            (settings, Ids::androidOboeRepositoryPath,            getUndoManager()),
           androidInternetNeeded                (settings, Ids::androidInternetNeeded,                getUndoManager(), true),
           androidMicNeeded                     (settings, Ids::microphonePermissionNeeded,           getUndoManager(), false),
+          androidCameraNeeded                  (settings, Ids::cameraPermissionNeeded,               getUndoManager(), false),
           androidBluetoothNeeded               (settings, Ids::androidBluetoothNeeded,               getUndoManager(), true),
           androidExternalReadPermission        (settings, Ids::androidExternalReadNeeded,            getUndoManager(), true),
           androidExternalWritePermission       (settings, Ids::androidExternalWriteNeeded,           getUndoManager(), true),
@@ -138,22 +142,22 @@ public:
           androidKeyStorePass                  (settings, Ids::androidKeyStorePass,                  getUndoManager(), "android"),
           androidKeyAlias                      (settings, Ids::androidKeyAlias,                      getUndoManager(), "androiddebugkey"),
           androidKeyAliasPass                  (settings, Ids::androidKeyAliasPass,                  getUndoManager(), "android"),
-          gradleVersion                        (settings, Ids::gradleVersion,                        getUndoManager(), "4.1"),
+          gradleVersion                        (settings, Ids::gradleVersion,                        getUndoManager(), "4.4"),
           gradleToolchain                      (settings, Ids::gradleToolchain,                      getUndoManager(), "clang"),
-          androidPluginVersion                 (settings, Ids::androidPluginVersion,                 getUndoManager(), "3.0.1"),
-          buildToolsVersion                    (settings, Ids::buildToolsVersion,                    getUndoManager(), "27.0.0"),
+          androidPluginVersion                 (settings, Ids::androidPluginVersion,                 getUndoManager(), "3.1.1"),
+          buildToolsVersion                    (settings, Ids::buildToolsVersion,                    getUndoManager(), "27.0.3"),
           AndroidExecutable (findAndroidExecutable())
     {
         name = getName();
 
-        targetLocationValue.setDefault (getDefaultBuildsRootFolder() + "Android");
+        targetLocationValue.setDefault (getDefaultBuildsRootFolder() + getTargetFolderForExporter (getValueTreeTypeName()));
     }
 
     //==============================================================================
     void createToolchainExporterProperties (PropertyListBuilder& props)
     {
         props.add (new TextPropertyComponent (gradleVersion, "gradle version", 32, false),
-                   "The version of gradle that is used to build this app (3.3 is fine for JUCE)");
+                   "The version of gradle that is used to build this app (4.4 is fine for JUCE)");
 
         props.add (new TextPropertyComponent (androidPluginVersion, "android plug-in version", 32, false),
                    "The version of the android build plugin for gradle that is used to build this app");
@@ -312,7 +316,9 @@ protected:
         AndroidBuildConfiguration (Project& p, const ValueTree& settings, const ProjectExporter& e)
             : BuildConfiguration (p, settings, e),
               androidArchitectures               (config, Ids::androidArchitectures,               getUndoManager(), isDebug() ? "armeabi x86" : ""),
+              androidBuildConfigRemoteNotifsConfigFile (config, Ids::androidBuildConfigRemoteNotifsConfigFile, getUndoManager()),
               androidAdditionalXmlValueResources (config, Ids::androidAdditionalXmlValueResources, getUndoManager()),
+              androidAdditionalDrawableResources (config, Ids::androidAdditionalDrawableResources, getUndoManager()),
               androidAdditionalRawValueResources (config, Ids::androidAdditionalRawValueResources, getUndoManager()),
               androidCustomStringXmlElements     (config, Ids::androidCustomStringXmlElements,     getUndoManager())
         {
@@ -320,10 +326,12 @@ protected:
             optimisationLevelValue.setDefault (isDebug() ? gccO0 : gccO3);
         }
 
-        String getArchitectures() const             { return androidArchitectures.get().toString(); }
-        String getAdditionalXmlResources() const    { return androidAdditionalXmlValueResources.get().toString(); }
-        String getAdditionalRawResources() const    { return androidAdditionalRawValueResources.get().toString();}
-        String getCustomStringsXml() const          { return androidCustomStringXmlElements.get().toString(); }
+        String getArchitectures() const               { return androidArchitectures.get().toString(); }
+        String getRemoteNotifsConfigFile() const      { return androidBuildConfigRemoteNotifsConfigFile.get().toString(); }
+        String getAdditionalXmlResources() const      { return androidAdditionalXmlValueResources.get().toString(); }
+        String getAdditionalDrawableResources() const { return androidAdditionalDrawableResources.get().toString(); }
+        String getAdditionalRawResources() const      { return androidAdditionalRawValueResources.get().toString();}
+        String getCustomStringsXml() const            { return androidCustomStringXmlElements.get().toString(); }
 
         void createConfigProperties (PropertyListBuilder& props) override
         {
@@ -332,11 +340,22 @@ protected:
             props.add (new TextPropertyComponent (androidArchitectures, "Architectures", 256, false),
                        "A list of the ARM architectures to build (for a fat binary). Leave empty to build for all possible android archiftectures.");
 
-            props.add (new TextPropertyComponent (androidAdditionalXmlValueResources, "Extra Android XML Value Resources", 2048, true),
+            props.add (new TextPropertyComponent (androidBuildConfigRemoteNotifsConfigFile.getPropertyAsValue(), "Remote Notifications Config File", 2048, false),
+                       "Path to google-services.json file. This will be the file provided by Firebase when creating a new app in Firebase console. "
+                       "This will override the setting from the main Android exporter node.");
+
+            props.add (new TextPropertyComponent (androidAdditionalXmlValueResources, "Extra Android XML Value Resources", 8192, true),
                        "Paths to additional \"value resource\" files in XML format that should be included in the app (one per line). "
                        "If you have additional XML resources that should be treated as value resources, add them here.");
 
-            props.add (new TextPropertyComponent (androidAdditionalRawValueResources, "Extra Android Raw Resources", 2048, true),
+            props.add (new TextPropertyComponent (androidAdditionalDrawableResources, "Extra Android Drawable Resources", 8192, true),
+                       "Paths to additional \"drawable resource\" directories that should be included in the app (one per line). "
+                       "They will be added to \"res\" directory of Android project. "
+                       "Each path should point to a directory named \"drawable\" or \"drawable-<size>\" where <size> should be "
+                       "something like \"hdpi\", \"ldpi\", \"xxxhdpi\" etc, for instance \"drawable-xhdpi\". "
+                       "Refer to Android Studio documentation for available sizes.");
+
+            props.add (new TextPropertyComponent (androidAdditionalRawValueResources, "Extra Android Raw Resources", 8192, true),
                        "Paths to additional \"raw resource\" files that should be included in the app (one per line). "
                        "Resource file names must contain only lowercase a-z, 0-9 or underscore.");
 
@@ -361,8 +380,9 @@ protected:
             return "${ANDROID_ABI}";
         }
 
-        ValueWithDefault androidArchitectures, androidAdditionalXmlValueResources, androidAdditionalRawValueResources,
-                         androidCustomStringXmlElements;
+        ValueWithDefault androidArchitectures, androidBuildConfigRemoteNotifsConfigFile,
+                         androidAdditionalXmlValueResources, androidAdditionalDrawableResources,
+                         androidAdditionalRawValueResources, androidCustomStringXmlElements;
     };
 
     BuildConfiguration::Ptr createBuildConfig (const ValueTree& v) const override
@@ -384,6 +404,14 @@ private:
         if (! isLibrary())
             mo << "SET(BINARY_NAME \"juce_jni\")" << newLine << newLine;
 
+        if (project.getConfigFlag ("JUCE_USE_ANDROID_OBOE").get())
+        {
+            String oboePath (androidOboeRepositoryPath.get().toString().quoted());
+
+            mo << "SET(OBOE_DIR " << oboePath << ")" << newLine << newLine;
+            mo << "add_subdirectory (${OBOE_DIR} ./oboe)" << newLine << newLine;
+        }
+
         String cpufeaturesPath ("${ANDROID_NDK}/sources/android/cpufeatures/cpu-features.c");
         mo << "add_library(\"cpufeatures\" STATIC \"" << cpufeaturesPath << "\")" << newLine
            << "set_source_files_properties(\"" << cpufeaturesPath << "\" PROPERTIES COMPILE_FLAGS \"-Wno-sign-conversion -Wno-gnu-statement-expression\")" << newLine << newLine;
@@ -401,6 +429,10 @@ private:
                 mo << "    \"" << escapeDirectoryForCmake (path) << "\"" << newLine;
 
             mo << "    \"${ANDROID_NDK}/sources/android/cpufeatures\"" << newLine;
+
+            if (project.getConfigFlag ("JUCE_USE_ANDROID_OBOE").get())
+                mo << "    \"${OBOE_DIR}/include\"" << newLine;
+
             mo << ")" << newLine << newLine;
         }
 
@@ -530,6 +562,10 @@ private:
 
             mo << "    \"cpufeatures\"" << newLine;
         }
+
+        if (project.getConfigFlag ("JUCE_USE_ANDROID_OBOE").get())
+            mo << "    \"oboe\"" << newLine;
+
         mo << ")" << newLine;
 
         overwriteFileIfDifferentOrThrow (file, mo);
@@ -542,8 +578,8 @@ private:
 
         mo << "buildscript {"                                                                              << newLine;
         mo << "   repositories {"                                                                          << newLine;
-        mo << "       jcenter()"                                                                           << newLine;
         mo << "       google()"                                                                            << newLine;
+        mo << "       jcenter()"                                                                           << newLine;
         mo << "   }"                                                                                       << newLine;
         mo << "   dependencies {"                                                                          << newLine;
         mo << "       classpath 'com.android.tools.build:gradle:" << androidPluginVersion.get().toString() << "'" << newLine;
@@ -556,6 +592,7 @@ private:
         mo << ""                                                                                       << newLine;
         mo << "allprojects {"                                                                          << newLine;
         mo << "   repositories {"                                                                      << newLine;
+        mo << "       google()"                                                                        << newLine;
         mo << "       jcenter()"                                                                       << newLine;
 
         if (androidEnableRemoteNotifications.get())
@@ -771,20 +808,20 @@ private:
     String getAndroidDependencies() const
     {
         MemoryOutputStream mo;
-
-        auto dependencies = StringArray::fromLines (androidDependencies.get().toString());
-
         mo << "dependencies {" << newLine;
 
+        for (auto& d : StringArray::fromLines (androidDependencies.get().toString()))
+            mo << "    " << d << newLine;
+
+        for (auto& d : StringArray::fromLines (androidJavaLibs.get().toString()))
+            mo << "    implementation files('libs/" << File (d).getFileName() << "')" << newLine;
+
         if (androidEnableRemoteNotifications.get())
         {
             mo << "    'com.google.firebase:firebase-core:11.4.0'" << newLine;
             mo << "    compile 'com.google.firebase:firebase-messaging:11.4.0'" << newLine;
         }
 
-        for (auto& d : dependencies)
-            mo << "    " << d << newLine;
-
         mo << "}" << newLine;
 
         return mo.toString();
@@ -824,11 +861,18 @@ private:
     //==============================================================================
     void createBaseExporterProperties (PropertyListBuilder& props)
     {
+        props.add (new TextPropertyComponent (androidJavaLibs, "Java libraries to include", 32768, true),
+                   "Java libs (JAR files) (one per line). These will be copied to app/libs folder and \"implementation files\" "
+                   "dependency will be automatically added to module \"dependencies\" section for each library, so do "
+                   "not add the dependency yourself.");
+
         props.add (new TextPropertyComponent (androidRepositories, "Module repositories", 32768, true),
                    "Module repositories (one per line). These will be added to module-level gradle file repositories section. ");
 
         props.add (new TextPropertyComponent (androidDependencies, "Module dependencies", 32768, true),
-                   "Module dependencies (one per line). These will be added to module-level gradle file dependencies section. ");
+                   "Module dependencies (one per line). These will be added to module-level gradle file \"dependencies\" section. "
+                   "If adding any java libs in \"Java libraries to include\" setting, do not add them here as "
+                   "they will be added automatically.");
 
         props.add (new ChoicePropertyComponent (androidScreenOrientation, "Screen orientation",
                                                 { "Portrait and Landscape", "Portrait", "Landscape" },
@@ -842,6 +886,12 @@ private:
                    "If not empty, specifies the Android Activity class name stored in the app's manifest. "
                    "Use this if you would like to use your own Android Activity sub-class.");
 
+        props.add (new TextPropertyComponent (androidActivityBaseClassName, "Android Activity base class", 256, false),
+                   "If not empty, specifies the base class to use for your activity. If custom base class is "
+                   "specified, that base class should be a sub-class of android.app.Activity. When empty, Activity "
+                   "(android.app.Activity) will be used as the base class. "
+                   "Use this if you would like to use your own Android Activity base class.");
+
         props.add (new TextPropertyComponent (androidVersionCode, "Android Version Code", 32, false),
                    "An integer value that represents the version of the application code, relative to other versions.");
 
@@ -861,12 +911,19 @@ private:
     //==============================================================================
     void createManifestExporterProperties (PropertyListBuilder& props)
     {
+        props.add (new TextPropertyComponent (androidOboeRepositoryPath, "Oboe repository path", 2048, false),
+                   "Path to the root of Oboe repository. Make sure to point Oboe repository to "
+                   "commit with SHA 44c6b6ea9c8fa9b5b74cbd60f355068b57b50b37 before building.");
+
         props.add (new ChoicePropertyComponent (androidInternetNeeded, "Internet Access"),
                    "If enabled, this will set the android.permission.INTERNET flag in the manifest.");
 
         props.add (new ChoicePropertyComponent (androidMicNeeded, "Audio Input Required"),
                    "If enabled, this will set the android.permission.RECORD_AUDIO flag in the manifest.");
 
+        props.add (new ChoicePropertyComponent (androidCameraNeeded, "Camera Required"),
+                   "If enabled, this will set the android.permission.CAMERA flag in the manifest.");
+
         props.add (new ChoicePropertyComponent (androidBluetoothNeeded, "Bluetooth permissions Required"),
                    "If enabled, this will set the android.permission.BLUETOOTH and  android.permission.BLUETOOTH_ADMIN flag in the manifest. This is required for Bluetooth MIDI on Android.");
 
@@ -958,11 +1015,14 @@ private:
             auto javaInAppBillingTarget = targetFolder.getChildFile ("app/src/main/java").getChildFile (inAppBillingPath);
             auto javaTarget = targetFolder.getChildFile ("app/src/main/java")
                                           .getChildFile (package.replaceCharacter ('.', File::getSeparatorChar()));
+            auto libTarget = targetFolder.getChildFile ("app/libs");
+            libTarget.createDirectory();
 
             copyActivityJavaFiles (javaSourceFolder, javaTarget, package);
             copyServicesJavaFiles (javaSourceFolder, javaTarget, package);
             copyProviderJavaFile  (javaSourceFolder, javaTarget, package);
             copyAdditionalJavaFiles (javaSourceFolder, javaInAppBillingTarget);
+            copyAdditionalJavaLibs (libTarget);
         }
     }
 
@@ -978,25 +1038,92 @@ private:
 
         createDirectoryOrThrow (targetFolder);
 
+        auto activityCode = getActivityCode (javaSourceFolder, className, package);
+
         auto javaDestFile = targetFolder.getChildFile (className + ".java");
+        overwriteFileIfDifferentOrThrow (javaDestFile, activityCode);
+    }
 
+    String getActivityCode (const File& javaSourceFolder, const String& className, const String& package) const
+    {
+        auto runtimePermissionsCode = getRuntimePermissionsCode (javaSourceFolder, className);
+        auto midiCode = getMidiCode (javaSourceFolder, className);
+        auto webViewCode = getWebViewCode (javaSourceFolder);
+        auto cameraCode = getCameraCode (javaSourceFolder);
 
-        String juceMidiCode, juceMidiImports, juceRuntimePermissionsCode;
+        auto javaSourceFile = javaSourceFolder.getChildFile ("JuceAppActivity.java");
+        auto javaSourceLines = StringArray::fromLines (javaSourceFile.loadFileAsString());
+
+        {
+            MemoryOutputStream newFile;
+
+            for (auto& line : javaSourceLines)
+            {
+                if (line.contains ("$$JuceAndroidMidiImports$$"))
+                    newFile << midiCode.imports;
+                else if (line.contains ("$$JuceAndroidMidiCode$$"))
+                    newFile << midiCode.main;
+                else if (line.contains ("$$JuceAndroidRuntimePermissionsCode$$"))
+                    newFile << runtimePermissionsCode;
+                else if (line.contains ("$$JuceAndroidWebViewImports$$"))
+                    newFile << webViewCode.imports;
+                else if (line.contains ("$$JuceAndroidWebViewNativeCode$$"))
+                    newFile << webViewCode.native;
+                else if (line.contains ("$$JuceAndroidWebViewCode$$"))
+                    newFile << webViewCode.main;
+                else if (line.contains ("$$JuceAndroidCameraImports$$"))
+                    newFile << cameraCode.imports;
+                else if (line.contains ("$$JuceAndroidCameraCode$$"))
+                    newFile << cameraCode.main;
+                else
+                    newFile << line.replace ("$$JuceAppActivityBaseClass$$", androidActivityBaseClassName.get().toString())
+                                   .replace ("JuceAppActivity", className)
+                                   .replace ("package com.juce;", "package " + package + ";") << newLine;
+            }
+
+            javaSourceLines = StringArray::fromLines (newFile.toString());
+        }
+
+        while (javaSourceLines.size() > 2
+                && javaSourceLines[javaSourceLines.size() - 1].trim().isEmpty()
+                && javaSourceLines[javaSourceLines.size() - 2].trim().isEmpty())
+            javaSourceLines.remove (javaSourceLines.size() - 1);
+
+        return javaSourceLines.joinIntoString (newLine);
+    }
+
+    String getRuntimePermissionsCode (const File& javaSourceFolder, const String& className) const
+    {
+        if (static_cast<int> (androidMinimumSDK.get()) >= 23)
+        {
+            auto javaRuntimePermissions = javaSourceFolder.getChildFile ("AndroidRuntimePermissions.java");
+            return javaRuntimePermissions.loadFileAsString().replace ("JuceAppActivity", className);
+        }
+
+        return {};
+    }
+
+    struct MidiCode
+    {
+        String imports;
+        String main;
+    };
+
+    MidiCode getMidiCode (const File& javaSourceFolder, const String& className) const
+    {
+        String juceMidiCode, juceMidiImports;
 
         juceMidiImports << newLine;
 
         if (static_cast<int> (androidMinimumSDK.get()) >= 23)
         {
             auto javaAndroidMidi = javaSourceFolder.getChildFile ("AndroidMidi.java");
-            auto javaRuntimePermissions = javaSourceFolder.getChildFile ("AndroidRuntimePermissions.java");
 
             juceMidiImports << "import android.media.midi.*;" << newLine
                             << "import android.bluetooth.*;" << newLine
                             << "import android.bluetooth.le.*;" << newLine;
 
             juceMidiCode = javaAndroidMidi.loadFileAsString().replace ("JuceAppActivity", className);
-
-            juceRuntimePermissionsCode = javaRuntimePermissions.loadFileAsString().replace ("JuceAppActivity", className);
         }
         else
         {
@@ -1005,6 +1132,18 @@ private:
                                            .replace ("JuceAppActivity", className);
         }
 
+        return { juceMidiImports, juceMidiCode };
+    }
+
+    struct WebViewCode
+    {
+        String imports;
+        String native;
+        String main;
+    };
+
+    WebViewCode getWebViewCode (const File& javaSourceFolder) const
+    {
         String juceWebViewImports, juceWebViewCodeNative, juceWebViewCode;
 
         if (static_cast<int> (androidMinimumSDK.get()) >= 23)
@@ -1050,40 +1189,32 @@ private:
             }
         }
 
-        auto javaSourceFile = javaSourceFolder.getChildFile ("JuceAppActivity.java");
-        auto javaSourceLines = StringArray::fromLines (javaSourceFile.loadFileAsString());
+        return { juceWebViewImports, juceWebViewCodeNative, juceWebViewCode };
+    }
 
+    struct CameraCode
+    {
+        String imports;
+        String main;
+    };
+
+    CameraCode getCameraCode (const File& javaSourceFolder) const
+    {
+        String juceCameraImports, juceCameraCode;
+
+        if (static_cast<int> (androidMinimumSDK.get()) >= 21)
+            juceCameraImports << "import android.hardware.camera2.*;" << newLine;
+
+        auto javaCameraFile = javaSourceFolder.getChildFile ("AndroidCamera.java");
+        auto juceCameraCodeAll = javaCameraFile.loadFileAsString();
+
+        if (static_cast<int> (androidMinimumSDK.get()) >= 21)
         {
-            MemoryOutputStream newFile;
-
-            for (auto& line : javaSourceLines)
-            {
-                if (line.contains ("$$JuceAndroidMidiImports$$"))
-                    newFile << juceMidiImports;
-                else if (line.contains ("$$JuceAndroidMidiCode$$"))
-                    newFile << juceMidiCode;
-                else if (line.contains ("$$JuceAndroidRuntimePermissionsCode$$"))
-                    newFile << juceRuntimePermissionsCode;
-                else if (line.contains ("$$JuceAndroidWebViewImports$$"))
-                    newFile << juceWebViewImports;
-                else if (line.contains ("$$JuceAndroidWebViewNativeCode$$"))
-                    newFile << juceWebViewCodeNative;
-                else if (line.contains ("$$JuceAndroidWebViewCode$$"))
-                    newFile << juceWebViewCode;
-                else
-                    newFile << line.replace ("JuceAppActivity", className)
-                                   .replace ("package com.juce;", "package " + package + ";") << newLine;
-            }
-
-            javaSourceLines = StringArray::fromLines (newFile.toString());
+            juceCameraCode << juceCameraCodeAll.fromFirstOccurrenceOf ("$$CameraApi21", false, false)
+                                               .upToFirstOccurrenceOf ("CameraApi21$$", false, false);
         }
 
-        while (javaSourceLines.size() > 2
-                && javaSourceLines[javaSourceLines.size() - 1].trim().isEmpty()
-                && javaSourceLines[javaSourceLines.size() - 2].trim().isEmpty())
-            javaSourceLines.remove (javaSourceLines.size() - 1);
-
-        overwriteFileIfDifferentOrThrow (javaDestFile, javaSourceLines.joinIntoString (newLine));
+        return { juceCameraImports, juceCameraCode };
     }
 
     void copyAdditionalJavaFiles (const File& sourceFolder, const File& targetFolder) const
@@ -1101,6 +1232,21 @@ private:
             inAppBillingJavaSrcFile.copyFileTo (inAppBillingJavaDestFile);
     }
 
+    void copyAdditionalJavaLibs (const File& targetFolder) const
+    {
+        auto libPaths = StringArray::fromLines (androidJavaLibs.get().toString());
+
+        for (auto& p : libPaths)
+        {
+            File f = getTargetFolder().getChildFile (p);
+
+            // Is the path to the java lib correct?
+            jassert (f.existsAsFile());
+
+            f.copyFileTo (targetFolder.getChildFile (f.getFileName()));
+        }
+    }
+
     void copyServicesJavaFiles (const File& javaSourceFolder, const File& targetFolder, const String& package) const
     {
         if (androidEnableRemoteNotifications.get())
@@ -1158,20 +1304,28 @@ private:
         for (ConstConfigIterator config (*this); config.next();)
         {
             auto& cfg = dynamic_cast<const AndroidBuildConfiguration&> (*config);
+            String cfgPath = cfg.isDebug() ? "app/src/debug" : "app/src/release";
             String xmlValuesPath = cfg.isDebug() ? "app/src/debug/res/values" : "app/src/release/res/values";
+            String drawablesPath = cfg.isDebug() ? "app/src/debug/res" : "app/src/release/res";
             String rawPath = cfg.isDebug() ? "app/src/debug/res/raw" : "app/src/release/res/raw";
 
             copyExtraResourceFiles (cfg.getAdditionalXmlResources(), xmlValuesPath);
+            copyExtraResourceFiles (cfg.getAdditionalDrawableResources(), drawablesPath);
             copyExtraResourceFiles (cfg.getAdditionalRawResources(), rawPath);
-        }
 
-        if (androidEnableRemoteNotifications.get())
-        {
-            File file (getProject().getFile().getChildFile (androidRemoteNotificationsConfigFile.get().toString()));
-            // Settings file must be present for remote notifications to work and it must be called google-services.json.
-            jassert (file.existsAsFile() && file.getFileName() == "google-services.json");
+            if (androidEnableRemoteNotifications.get())
+            {
+                auto remoteNotifsConfigFilePath = cfg.getRemoteNotifsConfigFile();
 
-            copyExtraResourceFiles (androidRemoteNotificationsConfigFile.get(), "app");
+                if (remoteNotifsConfigFilePath.isEmpty())
+                    remoteNotifsConfigFilePath = androidRemoteNotificationsConfigFile.get().toString();
+
+                File file (getProject().getFile().getChildFile (remoteNotifsConfigFilePath));
+                // Settings file must be present for remote notifications to work and it must be called google-services.json.
+                jassert (file.existsAsFile() && file.getFileName() == "google-services.json");
+
+                copyExtraResourceFiles (remoteNotifsConfigFilePath, cfgPath);
+            }
         }
     }
 
@@ -1187,9 +1341,9 @@ private:
         {
             auto file = getProject().getFile().getChildFile (path);
 
-            jassert (file.existsAsFile());
+            jassert (file.exists());
 
-            if (file.existsAsFile())
+            if (file.exists())
                 file.copyFileTo (parentFolder.getChildFile (file.getFileName()));
         }
     }
@@ -1252,7 +1406,7 @@ private:
             customStringsXmlContent << cfg.getCustomStringsXml();
             customStringsXmlContent << "\n</resources>";
 
-            ScopedPointer<XmlElement> strings = XmlDocument::parse (customStringsXmlContent);
+            std::unique_ptr<XmlElement> strings (XmlDocument::parse (customStringsXmlContent));
 
             String dir     = cfg.isDebug() ? "debug" : "release";
             String subPath = "app/src/" + dir + "/res/values/string.xml";
@@ -1263,7 +1417,7 @@ private:
 
     void writeAndroidManifest (const File& folder) const
     {
-        ScopedPointer<XmlElement> manifest (createManifestXML());
+        std::unique_ptr<XmlElement> manifest (createManifestXML());
 
         writeXmlOrThrow (*manifest, folder.getChildFile ("src/main/AndroidManifest.xml"), "utf-8", 100, true);
     }
@@ -1286,8 +1440,8 @@ private:
 
     void writeIcons (const File& folder) const
     {
-        ScopedPointer<Drawable> bigIcon (getBigIcon());
-        ScopedPointer<Drawable> smallIcon (getSmallIcon());
+        std::unique_ptr<Drawable> bigIcon (getBigIcon());
+        std::unique_ptr<Drawable> smallIcon (getSmallIcon());
 
         if (bigIcon != nullptr && smallIcon != nullptr)
         {
@@ -1383,7 +1537,7 @@ private:
 
         auto cppStandard = project.getCppStandardString();
 
-        if (cppStandard == "latest")
+        if (cppStandard == "latest" || cppStandard == "17") // C++17 flag isn't supported yet so use 1z for now
             cppStandard = "1z";
 
         cppStandard = "-std=" + String (shouldUseGNUExtensions() ? "gnu++" : "c++") + cppStandard;
@@ -1654,7 +1808,7 @@ private:
 
         if (! app->hasAttribute ("android:icon"))
         {
-            ScopedPointer<Drawable> bigIcon (getBigIcon()), smallIcon (getSmallIcon());
+            std::unique_ptr<Drawable> bigIcon (getBigIcon()), smallIcon (getSmallIcon());
 
             if (bigIcon != nullptr || smallIcon != nullptr)
                 app->setAttribute ("android:icon", "@drawable/icon");
@@ -1802,6 +1956,9 @@ private:
         if (androidMicNeeded.get())
             s.add ("android.permission.RECORD_AUDIO");
 
+        if (androidCameraNeeded.get())
+            s.add ("android.permission.CAMERA");
+
         if (androidBluetoothNeeded.get())
         {
             s.add ("android.permission.BLUETOOTH");
