@@ -180,7 +180,6 @@ public:
             {
                 case VSTPlugIn:
                 case DynamicLibrary:        return ".so";
-                case VST3PlugIn:            return ".vst3";
                 case SharedCodeTarget:
                 case StaticLibrary:         return ".a";
                 default:                    break;
@@ -328,7 +327,7 @@ public:
     {
         name = getNameLinux();
 
-        targetLocationValue.setDefault (getDefaultBuildsRootFolder() + "LinuxMakefile");
+        targetLocationValue.setDefault (getDefaultBuildsRootFolder() + getTargetFolderForExporter (getValueTreeTypeName()));
     }
 
     //==============================================================================
@@ -421,12 +420,7 @@ public:
     }
 
     //==============================================================================
-    void initialiseDependencyPathValues() override
-    {
-        vst3Path.referTo (Value (new DependencyPathValueSource (getSetting (Ids::vst3Folder),
-                                                                Ids::vst3Path,
-                                                                TargetOS::linux)));
-    }
+    void initialiseDependencyPathValues() override  {}
 
 private:
     ValueWithDefault extraPkgConfigValue;
@@ -535,7 +529,7 @@ private:
         auto cppStandard = project.getCppStandardString();
 
         if (cppStandard == "latest")
-            cppStandard = "1z";
+            cppStandard = "17";
 
         cppStandard = "-std=" + String (shouldUseGNUExtensions() ? "gnu++" : "c++") + cppStandard;
 
