@@ -96,6 +96,16 @@ StringArray ProjectExporter::getExporterNames()
     return s;
 }
 
+StringArray ProjectExporter::getExporterValueTreeNames()
+{
+    StringArray s;
+
+    for (auto& n : getExporterNames())
+        s.add (getValueTreeNameForExporter (n));
+
+    return s;
+}
+
 String ProjectExporter::getValueTreeNameForExporter (const String& exporterName)
 {
     if (exporterName == XcodeProjectExporter::getNameMac())
@@ -131,6 +141,22 @@ String ProjectExporter::getValueTreeNameForExporter (const String& exporterName)
     return {};
 }
 
+String ProjectExporter::getTargetFolderForExporter (const String& exporterValueTreeName)
+{
+    if (exporterValueTreeName == "XCODE_MAC")             return "MacOSX";
+    if (exporterValueTreeName == "XCODE_IPHONE")          return "iOS";
+    if (exporterValueTreeName == "VS2017")                return "VisualStudio2017";
+    if (exporterValueTreeName == "VS2015")                return "VisualStudio2015";
+    if (exporterValueTreeName == "VS2013")                return "VisualStudio2013";
+    if (exporterValueTreeName == "LINUX_MAKE")            return "LinuxMakefile";
+    if (exporterValueTreeName == "ANDROIDSTUDIO")         return "Android";
+    if (exporterValueTreeName == "CODEBLOCKS_WINDOWS")    return "CodeBlocksWindows";
+    if (exporterValueTreeName == "CODEBLOCKS_LINUX")      return "CodeBlocksLinux";
+    if (exporterValueTreeName == "CLION")                 return "CLion";
+
+    return {};
+}
+
 StringArray ProjectExporter::getAllDefaultBuildsFolders()
 {
     StringArray folders;
@@ -516,8 +542,8 @@ String ProjectExporter::getPathForModuleString (const String& moduleID) const
 
     if (exporterPath.isEmpty() || project.getModules().shouldUseGlobalPath (moduleID))
     {
-        auto id = EnabledModuleList::isJuceModule (moduleID) ? Ids::defaultJuceModulePath
-                                                             : Ids::defaultUserModulePath;
+        auto id = isJUCEModule (moduleID) ? Ids::defaultJuceModulePath
+                                          : Ids::defaultUserModulePath;
 
         if (TargetOS::getThisOS() != getTargetOSForExporter())
             return getAppSettings().getFallbackPathForOS (id, getTargetOSForExporter()).toString();
@@ -760,21 +786,21 @@ Image ProjectExporter::getBestIconForSize (int size, bool returnNullIfNothingBig
 {
     Drawable* im = nullptr;
 
-    ScopedPointer<Drawable> im1 (getSmallIcon());
-    ScopedPointer<Drawable> im2 (getBigIcon());
+    std::unique_ptr<Drawable> im1 (getSmallIcon());
+    std::unique_ptr<Drawable> im2 (getBigIcon());
 
     if (im1 != nullptr && im2 != nullptr)
     {
         if (im1->getWidth() >= size && im2->getWidth() >= size)
-            im = im1->getWidth() < im2->getWidth() ? im1 : im2;
+            im = im1->getWidth() < im2->getWidth() ? im1.get() : im2.get();
         else if (im1->getWidth() >= size)
-            im = im1;
+            im = im1.get();
         else if (im2->getWidth() >= size)
-            im = im2;
+            im = im2.get();
     }
     else
     {
-        im = im1 != nullptr ? im1 : im2;
+        im = im1 != nullptr ? im1.get() : im2.get();
     }
 
     if (im == nullptr)
@@ -894,21 +920,21 @@ void ProjectExporter::BuildConfiguration::createPropertyEditors (PropertyListBui
         props.add (new TextPropertyComponent (configNameValue, "Name", 96, false),
                    "The name of this configuration.");
 
-    props.add (new ChoicePropertyComponent (isDebugValue, "Debug mode"),
+    props.add (new ChoicePropertyComponent (isDebugValue, "Debug Mode"),
                "If enabled, this means that the configuration should be built with debug symbols.");
 
-    props.add (new TextPropertyComponent (targetNameValue, "Binary name", 256, false),
+    props.add (new TextPropertyComponent (targetNameValue, "Binary Name", 256, false),
                "The filename to use for the destination binary executable file. If you don't add a suffix to this name, "
                "a suitable platform-specific suffix will be added automatically.");
 
-    props.add (new TextPropertyComponent (targetBinaryPathValue, "Binary location", 1024, false),
+    props.add (new TextPropertyComponent (targetBinaryPathValue, "Binary Location", 1024, false),
                "The folder in which the finished binary should be placed. Leave this blank to cause the binary to be placed "
                "in its default location in the build folder.");
 
-    props.addSearchPathProperty (headerSearchPathValue, "Header search paths", "Extra header search paths.");
-    props.addSearchPathProperty (librarySearchPathValue, "Extra library search paths", "Extra library search paths.");
+    props.addSearchPathProperty (headerSearchPathValue, "Header Search Paths", "Extra header search paths.");
+    props.addSearchPathProperty (librarySearchPathValue, "Extra Library Search Paths", "Extra library search paths.");
 
-    props.add (new TextPropertyComponent (ppDefinesValue, "Preprocessor definitions", 32768, true),
+    props.add (new TextPropertyComponent (ppDefinesValue, "Preprocessor Definitions", 32768, true),
                "Extra preprocessor definitions. Use the form \"NAME1=value NAME2=value\", using whitespace, commas, or "
                "new-lines to separate the items - to include a space or comma in a definition, precede it with a backslash.");
 
