@@ -93,12 +93,14 @@ public:
 
             auto projectRootHash = project.getProjectRoot().toXmlString().hashCode();
 
+            if (project.getProjectType().isAudioPlugin())
+                writePluginCharacteristicsFile();
+
             writeAppConfigFile (modules, appConfigUserContent);
             writeBinaryDataFiles();
             writeAppHeader (modules);
             writeModuleCppWrappers (modules);
             writeProjects (modules, specifiedExporterToSave, ! showProgressBox);
-            writeAppConfigFile (modules, appConfigUserContent); // (this is repeated in case the projects added anything to it)
 
             // if the project root has changed after writing the other files then re-save it
             if (project.getProjectRoot().toXmlString().hashCode() != projectRootHash)
@@ -138,6 +140,29 @@ public:
         return Result::ok();
     }
 
+    Result saveContentNeededForLiveBuild()
+    {
+        OwnedArray<LibraryModule> modules;
+        project.getModules().createRequiredModules (modules);
+
+        checkModuleValidity (modules);
+
+        if (errors.size() == 0)
+        {
+            if (project.getProjectType().isAudioPlugin())
+                writePluginCharacteristicsFile();
+
+            writeAppConfigFile (modules, loadUserContentFromAppConfig());
+            writeBinaryDataFiles();
+            writeAppHeader (modules);
+            writeModuleCppWrappers (modules);
+
+            return Result::ok();
+        }
+
+        return Result::fail (errors[0]);
+    }
+
     Project::Item saveGeneratedFile (const String& filePath, const MemoryOutputStream& newData)
     {
         if (! generatedCodeFolder.createDirectory())
@@ -289,7 +314,7 @@ private:
 
     void writeMainProjectFile()
     {
-        ScopedPointer<XmlElement> xml (project.getProjectRoot().createXml());
+        std::unique_ptr<XmlElement> xml (project.getProjectRoot().createXml());
         jassert (xml != nullptr);
 
         if (xml != nullptr)
@@ -517,7 +542,7 @@ private:
             out << newLine;
         }
 
-        if (hasBinaryData && project.shouldIncludeBinaryInAppConfig())
+        if (hasBinaryData && project.shouldIncludeBinaryInJuceHeader())
             out << CodeHelpers::createIncludeStatement (project.getBinaryDataHeaderFile(), appConfigFile) << newLine;
 
         out << newLine
@@ -673,13 +698,13 @@ private:
 
         JobStatus runJob() override
         {
-            owner.saveExporter (exporter, modules);
+            owner.saveExporter (exporter.get(), modules);
             return jobHasFinished;
         }
 
     private:
         ProjectSaver& owner;
-        ScopedPointer<ProjectExporter> exporter;
+        std::unique_ptr<ProjectExporter> exporter;
         const OwnedArray<LibraryModule>& modules;
 
         JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (ExporterJob)
