@@ -108,8 +108,7 @@ void ProjucerLookAndFeel::drawButtonBackground (Graphics& g,
     const auto cornerSize = button.findParentComponentOfClass<PropertyComponent>() != nullptr ? 0.0f : 3.0f;
     const auto bounds = button.getLocalBounds().toFloat();
 
-    auto baseColour = backgroundColour.withMultipliedSaturation (button.hasKeyboardFocus (true) ? 1.3f : 0.9f)
-                                      .withMultipliedAlpha (button.isEnabled() ? 1.0f : 0.5f);
+    auto baseColour = backgroundColour.withMultipliedAlpha (button.isEnabled() ? 1.0f : 0.5f);
 
     if (isButtonDown || isMouseOverButton)
         baseColour = baseColour.contrasting (isButtonDown ? 0.2f : 0.05f);
@@ -162,7 +161,8 @@ void ProjucerLookAndFeel::drawToggleButton (Graphics& g, ToggleButton& button, b
         g.setOpacity (0.5f);
 
     bool isTextEmpty = button.getButtonText().isEmpty();
-    bool isPropertyComponentChild = (dynamic_cast<BooleanPropertyComponent*> (button.getParentComponent()) != nullptr);
+    bool isPropertyComponentChild = (dynamic_cast<BooleanPropertyComponent*> (button.getParentComponent()) != nullptr
+                                     || dynamic_cast<MultiChoicePropertyComponent*> (button.getParentComponent()) != nullptr);
 
     auto bounds = button.getLocalBounds();
 
@@ -197,11 +197,6 @@ void ProjucerLookAndFeel::drawToggleButton (Graphics& g, ToggleButton& button, b
     }
 }
 
-Font ProjucerLookAndFeel::getTextButtonFont (TextButton&, int buttonHeight)
-{
-    return Font (jmin (12.0f, buttonHeight * 0.6f));
-}
-
 void ProjucerLookAndFeel::fillTextEditorBackground (Graphics& g, int width, int height, TextEditor& textEditor)
 {
     g.setColour (textEditor.findColour (TextEditor::backgroundColourId));
