@@ -60,6 +60,8 @@ namespace juce
     listeners whenever one of its settings is changed.
 
     @see AudioDeviceSelectorComponent, AudioIODevice, AudioIODeviceType
+
+    @tags{Audio}
 */
 class JUCE_API  AudioDeviceManager  : public ChangeBroadcaster
 {
@@ -403,28 +405,44 @@ public:
     void playTestSound();
 
     //==============================================================================
-    /** Turns on level-measuring for input channels.
-        @see getCurrentInputLevel()
-    */
-    void enableInputLevelMeasurement (bool enableMeasurement) noexcept;
+    /**
+        A simple reference-counted struct that holds a level-meter value that can be read
+        using getCurrentLevel().
 
-    /** Turns on level-measuring for output channels.
-        @see getCurrentOutputLevel()
-    */
-    void enableOutputLevelMeasurement (bool enableMeasurement) noexcept;
+        This is used to ensure that the level processing code is only executed when something
+        holds a reference to one of these objects and will be bypassed otherwise.
 
-    /** Returns the current input level.
-        To use this, you must first enable it by calling enableInputLevelMeasurement().
-        @see enableInputLevelMeasurement()
+        @see getInputLevelGetter, getOutputLevelGetter
     */
-    double getCurrentInputLevel() const noexcept;
+    struct LevelMeter    : public ReferenceCountedObject
+    {
+        LevelMeter() noexcept;
+        double getCurrentLevel() const noexcept;
 
-    /** Returns the current output level.
-        To use this, you must first enable it by calling enableOutputLevelMeasurement().
-        @see enableOutputLevelMeasurement()
+        using Ptr = ReferenceCountedObjectPtr<LevelMeter>;
+
+    private:
+        friend class AudioDeviceManager;
+
+        Atomic<float> level { 0 };
+        void updateLevel (const float* const*, int numChannels, int numSamples) noexcept;
+    };
+
+    /** Returns a reference-counted object that can be used to get the current input level.
+
+        You need to store this object locally to ensure that the reference count is incremented
+        and decremented properly. The current input level value can be read using getCurrentLevel().
     */
-    double getCurrentOutputLevel() const noexcept;
+    LevelMeter::Ptr getInputLevelGetter() noexcept          { return inputLevelGetter; }
 
+    /** Returns a reference-counted object that can be used to get the current input level.
+
+        You need to store this object locally to ensure that the reference count is incremented
+        and decremented properly. The current input level value can be read using getCurrentLevel().
+    */
+    LevelMeter::Ptr getOutputLevelGetter() noexcept         { return outputLevelGetter; }
+
+    //==============================================================================
     /** Returns the a lock that can be used to synchronise access to the audio callback.
         Obviously while this is locked, you're blocking the audio thread from running, so
         it must only be used for very brief periods when absolutely necessary.
@@ -452,12 +470,12 @@ private:
     OwnedArray<AudioDeviceSetup> lastDeviceTypeConfigs;
 
     AudioDeviceSetup currentSetup;
-    ScopedPointer<AudioIODevice> currentAudioDevice;
+    std::unique_ptr<AudioIODevice> currentAudioDevice;
     Array<AudioIODeviceCallback*> callbacks;
     int numInputChansNeeded = 0, numOutputChansNeeded = 2;
     String currentDeviceType;
     BigInteger inputChannels, outputChannels;
-    ScopedPointer<XmlElement> lastExplicitSettings;
+    std::unique_ptr<XmlElement> lastExplicitSettings;
     mutable bool listNeedsScanning = true;
     AudioBuffer<float> tempBuffer;
 
@@ -472,33 +490,23 @@ private:
     Array<MidiCallbackInfo> midiCallbacks;
 
     String defaultMidiOutputName;
-    ScopedPointer<MidiOutput> defaultMidiOutput;
+    std::unique_ptr<MidiOutput> defaultMidiOutput;
     CriticalSection audioCallbackLock, midiCallbackLock;
 
-    ScopedPointer<AudioBuffer<float>> testSound;
+    std::unique_ptr<AudioBuffer<float>> testSound;
     int testSoundPosition = 0;
 
     double cpuUsageMs = 0, timeToCpuScale = 0, msPerBlock = 0;
     int xruns = 0;
 
-    struct LevelMeter
-    {
-        LevelMeter() noexcept;
-        void updateLevel (const float* const*, int numChannels, int numSamples) noexcept;
-        void setEnabled (bool) noexcept;
-        double getCurrentLevel() const noexcept;
-
-        Atomic<int> enabled;
-        Atomic<float> level;
-    };
-
-    LevelMeter inputLevelMeter, outputLevelMeter;
+    LevelMeter::Ptr inputLevelGetter   { new LevelMeter() },
+                    outputLevelGetter  { new LevelMeter() };
 
     //==============================================================================
     class CallbackHandler;
     friend class CallbackHandler;
     friend struct ContainerDeletePolicy<CallbackHandler>;
-    ScopedPointer<CallbackHandler> callbackHandler;
+    std::unique_ptr<CallbackHandler> callbackHandler;
 
     void audioDeviceIOCallbackInt (const float** inputChannelData, int totalNumInputChannels,
                                    float** outputChannelData, int totalNumOutputChannels, int numSamples);
