@@ -142,6 +142,15 @@
   */
   #include <jack/jack.h>
  #endif
+
+ #if JUCE_BELA
+  /* Got an include error here? If so, you've either not got the bela headers
+     installed, or you've not got your paths set up correctly to find its header
+     files.
+  */
+  #include <Bela.h>
+ #endif
+
  #undef SIZEOF
 
 //==============================================================================
@@ -153,6 +162,10 @@
   #include <SLES/OpenSLES_AndroidConfiguration.h>
  #endif
 
+ #if JUCE_USE_ANDROID_OBOE
+  #include <oboe/Oboe.h>
+ #endif
+
 #endif
 
 #include "audio_io/juce_AudioDeviceManager.cpp"
@@ -203,6 +216,10 @@
   #include "native/juce_linux_JackAudio.cpp"
  #endif
 
+ #if JUCE_BELA
+  #include "native/juce_linux_Bela.cpp"
+ #endif
+
 //==============================================================================
 #elif JUCE_ANDROID
  #include "native/juce_android_Audio.cpp"
@@ -211,6 +228,10 @@
  #if JUCE_USE_ANDROID_OPENSLES
   #include "native/juce_android_OpenSL.cpp"
  #endif
+
+ #if JUCE_USE_ANDROID_OBOE
+  #include "native/juce_android_Oboe.cpp"
+ #endif
 #endif
 
 #if ! JUCE_SYSTEMAUDIOVOL_IMPLEMENTED
