@@ -2,41 +2,40 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2015 - ROLI Ltd.
+   Copyright (c) 2017 - ROLI Ltd.
 
-   Permission is granted to use this software under the terms of either:
-   a) the GPL v2 (or any later version)
-   b) the Affero GPL v3
+   JUCE is an open source library subject to commercial or open-source
+   licensing.
 
-   Details of these licenses can be found at: www.gnu.org/licenses
+   The code included in this file is provided under the terms of the ISC license
+   http://www.isc.org/downloads/software-support-policy/isc-license. Permission
+   To use, copy, modify, and/or distribute this software for any purpose with or
+   without fee is hereby granted provided that the above copyright notice and
+   this permission notice appear in all copies.
 
-   JUCE is distributed in the hope that it will be useful, but WITHOUT ANY
-   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-   A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
-
-   ------------------------------------------------------------------------------
-
-   To release a closed-source product which uses JUCE, commercial licenses are
-   available: visit www.juce.com for more information.
+   JUCE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL WARRANTIES, WHETHER
+   EXPRESSED OR IMPLIED, INCLUDING MERCHANTABILITY AND FITNESS FOR PURPOSE, ARE
+   DISCLAIMED.
 
   ==============================================================================
 */
 
-#ifndef JUCE_MIDIDATACONCATENATOR_H_INCLUDED
-#define JUCE_MIDIDATACONCATENATOR_H_INCLUDED
+namespace juce
+{
 
 //==============================================================================
 /**
     Helper class that takes chunks of incoming midi bytes, packages them into
     messages, and dispatches them to a midi callback.
+
+    @tags{Audio}
 */
 class MidiDataConcatenator
 {
 public:
     //==============================================================================
-    MidiDataConcatenator (const int initialBufferSize)
-        : pendingData ((size_t) initialBufferSize),
-          pendingDataTime (0), pendingBytes (0), runningStatus (0)
+    MidiDataConcatenator (int initialBufferSize)
+        : pendingData ((size_t) initialBufferSize)
     {
     }
 
@@ -184,11 +183,11 @@ private:
     }
 
     MemoryBlock pendingData;
-    double pendingDataTime;
-    int pendingBytes;
-    uint8 runningStatus;
+    double pendingDataTime = 0;
+    int pendingBytes = 0;
+    uint8 runningStatus = 0;
 
     JUCE_DECLARE_NON_COPYABLE (MidiDataConcatenator)
 };
 
-#endif   // JUCE_MIDIDATACONCATENATOR_H_INCLUDED
+} // namespace juce
