@@ -969,6 +969,18 @@ struct iOSAudioIODevice::Pimpl      : public AudioPlayHead,
                                             dispatchAudioUnitPropertyChange,
                                             this);
         jassert (err == noErr);
+
+        AudioOutputUnitMIDICallbacks midiCallbacks;
+        midiCallbacks.userData = this;
+        midiCallbacks.MIDIEventProc = midiEventCallback;
+        midiCallbacks.MIDISysExProc = midiSysExCallback;
+        err = AudioUnitSetProperty (audioUnit,
+                                    kAudioOutputUnitProperty_MIDICallbacks,
+                                    kAudioUnitScope_Global,
+                                    0,
+                                    &midiCallbacks,
+                                    sizeof (midiCallbacks));
+        jassert (err == noErr);
        #endif
 
         if (channelData.areInputChannelsAvailable())
@@ -1125,10 +1137,9 @@ struct iOSAudioIODevice::Pimpl      : public AudioPlayHead,
         static_cast<Pimpl*> (data)->handleAudioUnitPropertyChange (unit, propertyID, scope, element);
     }
 
-    void handleMidiMessage (MidiMessage msg)
+    static double getTimestampForMIDI()
     {
-        if (messageCollector != nullptr)
-            messageCollector->addMessageToQueue (msg);
+        return Time::getMillisecondCounter() / 1000.0;
     }
 
     static void midiEventCallback (void *client, UInt32 status, UInt32 data1, UInt32 data2, UInt32)
@@ -1136,7 +1147,18 @@ struct iOSAudioIODevice::Pimpl      : public AudioPlayHead,
         return static_cast<Pimpl*> (client)->handleMidiMessage (MidiMessage ((int) status,
                                                                              (int) data1,
                                                                              (int) data2,
-                                                                             Time::getMillisecondCounter() / 1000.0));
+                                                                             getTimestampForMIDI()));
+    }
+
+    static void midiSysExCallback (void *client, const UInt8 *data, UInt32 length)
+    {
+        return static_cast<Pimpl*> (client)->handleMidiMessage (MidiMessage (data, (int) length, getTimestampForMIDI()));
+    }
+
+    void handleMidiMessage (MidiMessage msg)
+    {
+        if (messageCollector != nullptr)
+            messageCollector->addMessageToQueue (msg);
     }
 
     struct IOChannelData
@@ -1231,8 +1253,8 @@ struct iOSAudioIODevice::Pimpl      : public AudioPlayHead,
         void reconfigure (const BigInteger requiredInputChannels,
                           const BigInteger requiredOutputChannels)
         {
-            inputs  = new IOChannelConfig (true,  requiredInputChannels);
-            outputs = new IOChannelConfig (false, requiredOutputChannels);
+            inputs .reset (new IOChannelConfig (true,  requiredInputChannels));
+            outputs.reset (new IOChannelConfig (false, requiredOutputChannels));
 
             audioData.setSize (inputs->numActiveChannels + outputs->numActiveChannels,
                                audioData.getNumSamples());
@@ -1253,8 +1275,8 @@ struct iOSAudioIODevice::Pimpl      : public AudioPlayHead,
             return inputs->areChannelsAccessible && inputs->numActiveChannels > 0;
         }
 
-        ScopedPointer<IOChannelConfig> inputs;
-        ScopedPointer<IOChannelConfig> outputs;
+        std::unique_ptr<IOChannelConfig> inputs;
+        std::unique_ptr<IOChannelConfig> outputs;
 
         AudioBuffer<float> audioData { 0, 0 };
     };
@@ -1350,7 +1372,7 @@ int iOSAudioIODevice::getOutputLatencyInSamples()                   { return rou
 int iOSAudioIODevice::getXRunCount() const noexcept                 { return pimpl->xrun; }
 
 void iOSAudioIODevice::setMidiMessageCollector (MidiMessageCollector* collector) { pimpl->messageCollector = collector; }
-AudioPlayHead* iOSAudioIODevice::getAudioPlayHead() const           { return pimpl; }
+AudioPlayHead* iOSAudioIODevice::getAudioPlayHead() const           { return pimpl.get(); }
 
 bool iOSAudioIODevice::isInterAppAudioConnected() const             { return pimpl->interAppAudioConnected; }
 #if JUCE_MODULE_AVAILABLE_juce_graphics
