@@ -58,7 +58,7 @@ static void getDeviceSampleRates (snd_pcm_t* handle, Array<double>& rates)
     for (int i = 0; ratesToTry[i] != 0; ++i)
     {
         if (snd_pcm_hw_params_any (handle, hwParams) >= 0
-            && snd_pcm_hw_params_test_rate (handle, hwParams, (unsigned int) ratesToTry[i], 0) == 0)
+             && snd_pcm_hw_params_test_rate (handle, hwParams, (unsigned int) ratesToTry[i], 0) == 0)
         {
             rates.addIfNotAlreadyThere ((double) ratesToTry[i]);
         }
@@ -240,12 +240,12 @@ public:
                 const int type = formatsToTry [i + 1];
                 bitDepth = type & 255;
 
-                converter = createConverter (isInput, bitDepth,
-                                             (type & isFloatBit) != 0,
-                                             (type & isLittleEndianBit) != 0,
-                                             (type & onlyUseLower24Bits) != 0,
-                                             numChannels,
-                                             isInterleaved);
+                converter.reset (createConverter (isInput, bitDepth,
+                                                  (type & isFloatBit) != 0,
+                                                  (type & isLittleEndianBit) != 0,
+                                                  (type & onlyUseLower24Bits) != 0,
+                                                  numChannels,
+                                                  isInterleaved));
                 break;
             }
         }
@@ -358,7 +358,7 @@ public:
             scratch.ensureSize ((size_t) ((int) sizeof (float) * numSamples * numChannelsRunning), false);
             scratch.fillWith (0); // (not clearing this data causes warnings in valgrind)
 
-            snd_pcm_sframes_t num = snd_pcm_readi (handle, scratch.getData(), (snd_pcm_uframes_t) numSamples);
+            auto num = snd_pcm_readi (handle, scratch.getData(), (snd_pcm_uframes_t) numSamples);
 
             if (num < 0)
             {
@@ -378,7 +378,7 @@ public:
         }
         else
         {
-            snd_pcm_sframes_t num = snd_pcm_readn (handle, (void**) data, (snd_pcm_uframes_t) numSamples);
+            auto num = snd_pcm_readn (handle, (void**) data, (snd_pcm_uframes_t) numSamples);
 
             if (num < 0)
             {
@@ -411,7 +411,7 @@ private:
     const bool isInput;
     bool isInterleaved;
     MemoryBlock scratch;
-    ScopedPointer<AudioData::Converter> converter;
+    std::unique_ptr<AudioData::Converter> converter;
 
     //==============================================================================
     template <class SampleType>
@@ -431,7 +431,7 @@ private:
         {
             if (forInput)
             {
-                typedef AudioData::Pointer <AudioData::Float32, AudioData::NativeEndian, AudioData::NonInterleaved, AudioData::NonConst> DestType;
+                using DestType = AudioData::Pointer <AudioData::Float32, AudioData::NativeEndian, AudioData::NonInterleaved, AudioData::NonConst>;
 
                 if (isLittleEndian)
                     return new AudioData::ConverterInstance <AudioData::Pointer <SampleType, AudioData::LittleEndian, InterleavedType, AudioData::Const>, DestType> (numInterleavedChannels, 1);
@@ -439,7 +439,7 @@ private:
                 return new AudioData::ConverterInstance <AudioData::Pointer <SampleType, AudioData::BigEndian, InterleavedType, AudioData::Const>, DestType> (numInterleavedChannels, 1);
             }
 
-            typedef AudioData::Pointer <AudioData::Float32, AudioData::NativeEndian, AudioData::NonInterleaved, AudioData::Const> SourceType;
+            using SourceType = AudioData::Pointer <AudioData::Float32, AudioData::NativeEndian, AudioData::NonInterleaved, AudioData::Const>;
 
             if (isLittleEndian)
                 return new AudioData::ConverterInstance <SourceType, AudioData::Pointer <SampleType, AudioData::LittleEndian, InterleavedType, AudioData::NonConst>> (1, numInterleavedChannels);
@@ -488,17 +488,8 @@ class ALSAThread  : public Thread
 public:
     ALSAThread (const String& inputDeviceID, const String& outputDeviceID)
         : Thread ("JUCE ALSA"),
-          sampleRate (0),
-          bufferSize (0),
-          outputLatency (0),
-          inputLatency (0),
-          callback (0),
           inputId (inputDeviceID),
-          outputId (outputDeviceID),
-          numCallbacks (0),
-          audioIoInProgress (false),
-          inputChannelBuffer (1, 1),
-          outputChannelBuffer (1, 1)
+          outputId (outputDeviceID)
     {
         initialiseRatesAndChannels();
     }
@@ -510,8 +501,8 @@ public:
 
     void open (BigInteger inputChannels,
                BigInteger outputChannels,
-               const double newSampleRate,
-               const int newBufferSize)
+               double newSampleRate,
+               int newBufferSize)
     {
         close();
 
@@ -549,6 +540,35 @@ public:
         outputChannelDataForCallback.clear();
         currentOutputChans.clear();
 
+        // Note that the input device is opened before an output, because we've heard
+        // of drivers where doing it in the reverse order mysteriously fails.. If this
+        // order also causes problems, let us know and we'll see if we can find a compromise!
+
+        if (inputChannelDataForCallback.size() > 0 && inputId.isNotEmpty())
+        {
+            inputDevice.reset (new ALSADevice (inputId, true));
+
+            if (inputDevice->error.isNotEmpty())
+            {
+                error = inputDevice->error;
+                inputDevice.reset();
+                return;
+            }
+
+            ensureMinimumNumBitsSet (currentInputChans, (int) minChansIn);
+
+            if (! inputDevice->setParameters ((unsigned int) sampleRate,
+                                              jlimit ((int) minChansIn, (int) maxChansIn, currentInputChans.getHighestBit() + 1),
+                                              bufferSize))
+            {
+                error = inputDevice->error;
+                inputDevice.reset();
+                return;
+            }
+
+            inputLatency = inputDevice->latency;
+        }
+
         if (outputChannels.getHighestBit() >= 0)
         {
             for (int i = 0; i < maxOutputsRequested; ++i)
@@ -563,12 +583,12 @@ public:
 
         if (outputChannelDataForCallback.size() > 0 && outputId.isNotEmpty())
         {
-            outputDevice = new ALSADevice (outputId, false);
+            outputDevice.reset (new ALSADevice (outputId, false));
 
             if (outputDevice->error.isNotEmpty())
             {
                 error = outputDevice->error;
-                outputDevice = nullptr;
+                outputDevice.reset();
                 return;
             }
 
@@ -578,38 +598,13 @@ public:
                                                bufferSize))
             {
                 error = outputDevice->error;
-                outputDevice = nullptr;
+                outputDevice.reset();
                 return;
             }
 
             outputLatency = outputDevice->latency;
         }
 
-        if (inputChannelDataForCallback.size() > 0 && inputId.isNotEmpty())
-        {
-            inputDevice = new ALSADevice (inputId, true);
-
-            if (inputDevice->error.isNotEmpty())
-            {
-                error = inputDevice->error;
-                inputDevice = nullptr;
-                return;
-            }
-
-            ensureMinimumNumBitsSet (currentInputChans, (int) minChansIn);
-
-            if (! inputDevice->setParameters ((unsigned int) sampleRate,
-                                              jlimit ((int) minChansIn, (int) maxChansIn, currentInputChans.getHighestBit() + 1),
-                                              bufferSize))
-            {
-                error = inputDevice->error;
-                inputDevice = nullptr;
-                return;
-            }
-
-            inputLatency = inputDevice->latency;
-        }
-
         if (outputDevice == nullptr && inputDevice == nullptr)
         {
             error = "no channels";
@@ -664,8 +659,8 @@ public:
 
         stopThread (6000);
 
-        inputDevice = nullptr;
-        outputDevice = nullptr;
+        inputDevice.reset();
+        outputDevice.reset();
 
         inputChannelBuffer.setSize (1, 1);
         outputChannelBuffer.setSize (1, 1);
@@ -692,7 +687,7 @@ public:
                     if (threadShouldExit())
                         break;
 
-                    snd_pcm_sframes_t avail = snd_pcm_avail_update (inputDevice->handle);
+                    auto avail = snd_pcm_avail_update (inputDevice->handle);
 
                     if (avail < 0)
                         JUCE_ALSA_FAILED (snd_pcm_recover (inputDevice->handle, (int) avail, 0));
@@ -738,7 +733,7 @@ public:
                 if (threadShouldExit())
                     break;
 
-                snd_pcm_sframes_t avail = snd_pcm_avail_update (outputDevice->handle);
+                auto avail = snd_pcm_avail_update (outputDevice->handle);
 
                 if (avail < 0)
                     JUCE_ALSA_FAILED (snd_pcm_recover (outputDevice->handle, (int) avail, 0));
@@ -784,20 +779,20 @@ public:
 
     //==============================================================================
     String error;
-    double sampleRate;
-    int bufferSize, outputLatency, inputLatency;
+    double sampleRate = 0;
+    int bufferSize = 0, outputLatency = 0, inputLatency = 0;
     BigInteger currentInputChans, currentOutputChans;
 
     Array<double> sampleRates;
     StringArray channelNamesOut, channelNamesIn;
-    AudioIODeviceCallback* callback;
+    AudioIODeviceCallback* callback = nullptr;
 
 private:
     //==============================================================================
     const String inputId, outputId;
-    ScopedPointer<ALSADevice> outputDevice, inputDevice;
-    int numCallbacks;
-    bool audioIoInProgress;
+    std::unique_ptr<ALSADevice> outputDevice, inputDevice;
+    int numCallbacks = 0;
+    bool audioIoInProgress = false;
 
     CriticalSection callbackLock;
 
@@ -805,8 +800,8 @@ private:
     Array<const float*> inputChannelDataForCallback;
     Array<float*> outputChannelDataForCallback;
 
-    unsigned int minChansOut, maxChansOut;
-    unsigned int minChansIn, maxChansIn;
+    unsigned int minChansOut = 0, maxChansOut = 0;
+    unsigned int minChansIn = 0, maxChansIn = 0;
 
     bool failed (const int errorNum)
     {
@@ -854,8 +849,6 @@ public:
         : AudioIODevice (deviceName, deviceTypeName),
           inputId (inputDeviceID),
           outputId (outputDeviceID),
-          isOpen_ (false),
-          isStarted (false),
           internal (inputDeviceID, outputDeviceID)
     {
     }
@@ -958,7 +951,7 @@ public:
 
     void stop() override
     {
-        AudioIODeviceCallback* const oldCallback = internal.callback;
+        auto oldCallback = internal.callback;
 
         start (nullptr);
 
@@ -969,7 +962,7 @@ public:
     String inputId, outputId;
 
 private:
-    bool isOpen_, isStarted;
+    bool isOpen_ = false, isStarted = false;
     ALSAThread internal;
 };
 
@@ -978,9 +971,8 @@ private:
 class ALSAAudioIODeviceType  : public AudioIODeviceType
 {
 public:
-    ALSAAudioIODeviceType (bool onlySoundcards, const String &deviceTypeName)
+    ALSAAudioIODeviceType (bool onlySoundcards, const String& deviceTypeName)
         : AudioIODeviceType (deviceTypeName),
-          hasScanned (false),
           listOnlySoundcards (onlySoundcards)
     {
        #if ! JUCE_ALSA_LOGGING
@@ -1031,7 +1023,7 @@ public:
     {
         jassert (hasScanned); // need to call scanForDevices() before doing this
 
-        const int idx = (forInput ? inputIds : outputIds).indexOf ("default");
+        auto idx = (forInput ? inputIds : outputIds).indexOf ("default");
         return idx >= 0 ? idx : 0;
     }
 
@@ -1041,7 +1033,7 @@ public:
     {
         jassert (hasScanned); // need to call scanForDevices() before doing this
 
-        if (ALSAAudioIODevice* d = dynamic_cast<ALSAAudioIODevice*> (device))
+        if (auto* d = dynamic_cast<ALSAAudioIODevice*> (device))
             return asInput ? inputIds.indexOf (d->inputId)
                            : outputIds.indexOf (d->outputId);
 
@@ -1053,8 +1045,8 @@ public:
     {
         jassert (hasScanned); // need to call scanForDevices() before doing this
 
-        const int inputIndex = inputNames.indexOf (inputDeviceName);
-        const int outputIndex = outputNames.indexOf (outputDeviceName);
+        auto inputIndex = inputNames.indexOf (inputDeviceName);
+        auto outputIndex = outputNames.indexOf (outputDeviceName);
 
         String deviceName (outputIndex >= 0 ? outputDeviceName
                                             : inputDeviceName);
@@ -1070,9 +1062,10 @@ public:
 private:
     //==============================================================================
     StringArray inputNames, outputNames, inputIds, outputIds;
-    bool hasScanned, listOnlySoundcards;
+    bool hasScanned = false;
+    const bool listOnlySoundcards;
 
-    bool testDevice (const String &id, const String &outputName, const String &inputName)
+    bool testDevice (const String& id, const String& outputName, const String& inputName)
     {
         unsigned int minChansOut = 0, maxChansOut = 0;
         unsigned int minChansIn = 0, maxChansIn = 0;
@@ -1265,7 +1258,7 @@ private:
             testDevice ("pulse", "Pulseaudio output", "Pulseaudio input");
 
         // make sure the default device is listed first, and followed by the pulse device (if present)
-        int idx = outputIds.indexOf ("pulse");
+        auto idx = outputIds.indexOf ("pulse");
         outputIds.move (idx, 0);
         outputNames.move (idx, 0);
 
@@ -1284,8 +1277,8 @@ private:
 
     static String hintToString (const void* hints, const char* type)
     {
-        char* const hint = snd_device_name_get_hint (hints, type);
-        const String s (String::fromUTF8 (hint));
+        char* hint = snd_device_name_get_hint (hints, type);
+        auto s = String::fromUTF8 (hint);
         ::free (hint);
         return s;
     }
