@@ -79,6 +79,7 @@
 #include "../utility/juce_FakeMouseMoveGenerator.h"
 #include "../utility/juce_WindowsHooks.h"
 
+#include "../../juce_audio_processors/format_types/juce_LegacyAudioParameter.cpp"
 #include "../../juce_audio_processors/format_types/juce_VSTCommon.h"
 
 #ifdef _MSC_VER
@@ -222,7 +223,8 @@ struct AbletonLiveHostSpecific
 class JuceVSTWrapper  : public AudioProcessorListener,
                         public AudioPlayHead,
                         private Timer,
-                        private AsyncUpdater
+                        private AsyncUpdater,
+                        private AudioProcessorParameter::Listener
 {
 private:
     //==============================================================================
@@ -260,6 +262,8 @@ public:
        : hostCallback (cb),
          processor (af)
     {
+        inParameterChangedCallback = false;
+
         // VST-2 does not support disabling buses: so always enable all of them
         processor->enableAllBuses();
 
@@ -279,6 +283,11 @@ public:
         processor->setPlayHead (this);
         processor->addListener (this);
 
+        if (auto* juceParam = processor->getBypassParameter())
+            juceParam->addListener (this);
+
+        juceParameters.update (*processor, false);
+
         memset (&vstEffect, 0, sizeof (vstEffect));
         vstEffect.interfaceIdentifier = juceVstInterfaceIdentifier;
         vstEffect.dispatchFunction = dispatcherCB;
@@ -286,7 +295,7 @@ public:
         vstEffect.setParameterValueFunction = setParameterCB;
         vstEffect.getParameterValueFunction = getParameterCB;
         vstEffect.numPrograms = jmax (1, af->getNumPrograms());
-        vstEffect.numParameters = af->getNumParameters();
+        vstEffect.numParameters = juceParameters.getNumParameters();
         vstEffect.numInputChannels = maxNumInChannels;
         vstEffect.numOutputChannels = maxNumOutChannels;
         vstEffect.latency = processor->getLatencySamples();
@@ -704,11 +713,10 @@ public:
     //==============================================================================
     float getParameter (int32 index) const
     {
-        if (processor == nullptr)
-            return 0.0f;
+        if (auto* param = juceParameters.getParamForIndex (index))
+            return param->getValue();
 
-        jassert (isPositiveAndBelow (index, processor->getNumParameters()));
-        return processor->getParameter (index);
+        return 0.0f;
     }
 
     static float getParameterCB (VstEffectInterface* vstInterface, int32 index)
@@ -718,10 +726,12 @@ public:
 
     void setParameter (int32 index, float value)
     {
-        if (processor != nullptr)
+        if (auto* param = juceParameters.getParamForIndex (index))
         {
-            jassert (isPositiveAndBelow (index, processor->getNumParameters()));
-            processor->setParameter (index, value);
+            param->setValue (value);
+
+            inParameterChangedCallback = true;
+            param->sendValueChangedMessageToListeners (value);
         }
     }
 
@@ -732,6 +742,12 @@ public:
 
     void audioProcessorParameterChanged (AudioProcessor*, int index, float newValue) override
     {
+        if (inParameterChangedCallback.get())
+        {
+            inParameterChangedCallback = false;
+            return;
+        }
+
         if (hostCallback != nullptr)
             hostCallback (&vstEffect, hostOpcodeParameterChanged, index, 0, 0, newValue);
     }
@@ -748,6 +764,14 @@ public:
             hostCallback (&vstEffect, hostOpcodeParameterChangeGestureEnd, index, 0, 0, 0);
     }
 
+    void parameterValueChanged (int, float newValue) override
+    {
+        // this can only come from the bypass parameter
+        isBypassed = (newValue != 0.0f);
+    }
+
+    void parameterGestureChanged (int, bool) override {}
+
     void audioProcessorChanged (AudioProcessor*) override
     {
         vstEffect.latency = processor->getLatencySamples();
@@ -1048,7 +1072,7 @@ public:
             if (auto* ed = processor->createEditorIfNeeded())
             {
                 vstEffect.flags |= vstEffectFlagHasEditor;
-                editorComp = new EditorCompWrapper (*this, *ed);
+                editorComp.reset (new EditorCompWrapper (*this, *ed));
 
                #if ! (JUCE_MAC || JUCE_IOS)
                 ed->setScaleFactor (editorScaleFactor);
@@ -1196,7 +1220,7 @@ public:
 
         ~EditorCompWrapper()
         {
-            deleteAllChildren(); // note that we can't use a ScopedPointer because the editor may
+            deleteAllChildren(); // note that we can't use a std::unique_ptr because the editor may
                                  // have been transferred to another parent which takes over ownership.
         }
 
@@ -1264,10 +1288,12 @@ public:
             if (auto* ed = getEditorComp())
             {
                 ed->setTopLeftPosition (0, 0);
-                ed->setBounds (ed->getLocalArea (this, getLocalBounds()));
+
+                if (shouldResizeEditor)
+                    ed->setBounds (ed->getLocalArea (this, getLocalBounds()));
 
                 if (! getHostType().isBitwigStudio())
-                    updateWindowSize();
+                    updateWindowSize (false);
             }
 
            #if JUCE_MAC && ! JUCE_64BIT
@@ -1278,7 +1304,7 @@ public:
 
         void childBoundsChanged (Component*) override
         {
-            updateWindowSize();
+            updateWindowSize (false);
         }
 
         juce::Rectangle<int> getSizeToContainChild()
@@ -1289,7 +1315,7 @@ public:
             return {};
         }
 
-        void updateWindowSize()
+        void updateWindowSize (bool resizeEditor)
         {
             if (! isInSizeWindow)
             {
@@ -1306,8 +1332,14 @@ public:
                     resizeHostWindow (pos.getWidth(), pos.getHeight());
 
                    #if ! JUCE_LINUX // setSize() on linux causes renoise and energyxt to fail.
+                    if (! resizeEditor) // this is needed to prevent an infinite resizing loop due to coordinate rounding
+                        shouldResizeEditor = false;
+
                     setSize (pos.getWidth(), pos.getHeight());
+
+                    shouldResizeEditor = true;
                    #else
+                    ignoreUnused (resizeEditor);
                     XResizeWindow (display.display, (Window) getWindowHandle(), pos.getWidth(), pos.getHeight());
                    #endif
 
@@ -1425,6 +1457,7 @@ public:
         JuceVSTWrapper& wrapper;
         FakeMouseMoveGenerator fakeMouseGenerator;
         bool isInSizeWindow = false;
+        bool shouldResizeEditor = true;
 
        #if JUCE_MAC
         void* hostWindow = {};
@@ -1448,12 +1481,14 @@ private:
     VstEffectInterface vstEffect;
     juce::MemoryBlock chunkMemory;
     juce::uint32 chunkMemoryTime = 0;
-    ScopedPointer<EditorCompWrapper> editorComp;
+    std::unique_ptr<EditorCompWrapper> editorComp;
     VstEditorBounds editorBounds;
     MidiBuffer midiEvents;
     VSTMidiEventList outgoingEvents;
     float editorScaleFactor = 1.0f;
 
+    LegacyAudioParametersWrapper juceParameters;
+
     bool isProcessing = false, isBypassed = false, hasShutdown = false;
     bool firstProcessCallback = true, shouldDeleteEditor = false;
 
@@ -1469,6 +1504,8 @@ private:
 
     HeapBlock<VstSpeakerConfiguration> cachedInArrangement, cachedOutArrangement;
 
+    ThreadLocalValue<bool> inParameterChangedCallback;
+
     static JuceVSTWrapper* getWrapper (VstEffectInterface* v) noexcept  { return static_cast<JuceVSTWrapper*> (v->effectPointer); }
 
     bool isProcessLevelOffline()
@@ -1644,11 +1681,10 @@ private:
 
     pointer_sized_int handleGetParameterLabel (VstOpCodeArguments args)
     {
-        if (processor != nullptr)
+        if (auto* param = juceParameters.getParamForIndex (args.index))
         {
-            jassert (isPositiveAndBelow (args.index, processor->getNumParameters()));
             // length should technically be kVstMaxParamStrLen, which is 8, but hosts will normally allow a bit more.
-            processor->getParameterLabel (args.index).copyToUTF8 ((char*) args.ptr, 24 + 1);
+            param->getLabel().copyToUTF8 ((char*) args.ptr, 24 + 1);
         }
 
         return 0;
@@ -1656,11 +1692,10 @@ private:
 
     pointer_sized_int handleGetParameterText (VstOpCodeArguments args)
     {
-        if (processor != nullptr)
+        if (auto* param = juceParameters.getParamForIndex (args.index))
         {
-            jassert (isPositiveAndBelow (args.index, processor->getNumParameters()));
             // length should technically be kVstMaxParamStrLen, which is 8, but hosts will normally allow a bit more.
-            processor->getParameterText (args.index, 24).copyToUTF8 ((char*) args.ptr, 24 + 1);
+            param->getCurrentValueAsText().copyToUTF8 ((char*) args.ptr, 24 + 1);
         }
 
         return 0;
@@ -1668,11 +1703,10 @@ private:
 
     pointer_sized_int handleGetParameterName (VstOpCodeArguments args)
     {
-        if (processor != nullptr)
+        if (auto* param = juceParameters.getParamForIndex (args.index))
         {
-            jassert (isPositiveAndBelow (args.index, processor->getNumParameters()));
             // length should technically be kVstMaxParamStrLen, which is 8, but hosts will normally allow a bit more.
-            processor->getParameterName (args.index, 32).copyToUTF8 ((char*) args.ptr, 32 + 1);
+            param->getName (32).copyToUTF8 ((char*) args.ptr, 32 + 1);
         }
 
         return 0;
@@ -1803,22 +1837,27 @@ private:
 
     pointer_sized_int handleIsParameterAutomatable (VstOpCodeArguments args)
     {
-        if (processor == nullptr)
-            return 0;
+        if (auto* param = juceParameters.getParamForIndex (args.index))
+        {
+            const bool isMeter = (((param->getCategory() & 0xffff0000) >> 16) == 2);
+            return (param->isAutomatable() && (! isMeter) ? 1 : 0);
+        }
 
-        const bool isMeter = (((processor->getParameterCategory (args.index) & 0xffff0000) >> 16) == 2);
-        return (processor->isParameterAutomatable (args.index) && (! isMeter) ? 1 : 0);
+        return 0;
     }
 
     pointer_sized_int handleParameterValueForText (VstOpCodeArguments args)
     {
-        if (processor != nullptr)
+        if (auto* param = juceParameters.getParamForIndex (args.index))
         {
-            jassert (isPositiveAndBelow (args.index, processor->getNumParameters()));
-
-            if (auto* p = processor->getParameters()[args.index])
+            if (! LegacyAudioParameter::isLegacy (param))
             {
-                processor->setParameter (args.index, p->getValueForText (String::fromUTF8 ((char*) args.ptr)));
+                auto value = param->getValueForText (String::fromUTF8 ((char*) args.ptr));
+                param->setValue (value);
+
+                inParameterChangedCallback = true;
+                param->sendValueChangedMessageToListeners (value);
+
                 return 1;
             }
         }
@@ -1903,6 +1942,10 @@ private:
     pointer_sized_int handleSetBypass (VstOpCodeArguments args)
     {
         isBypassed = (args.value != 0);
+
+        if (auto* bypass = processor->getBypassParameter())
+            bypass->setValueNotifyingHost (isBypassed ? 1.0f : 0.0f);
+
         return 1;
     }
 
@@ -1931,6 +1974,9 @@ private:
         if (args.index == presonusVendorID && args.value == presonusSetContentScaleFactor)
             return handleSetContentScaleFactor (args.opt);
 
+        if (args.index == plugInOpcodeGetParameterText)
+            return handleCockosGetParameterText (args.value, args.ptr, args.opt);
+
         if (auto callbackHandler = dynamic_cast<VSTCallbackHandler*> (processor))
             return callbackHandler->handleVstManufacturerSpecific (args.index, args.value, args.ptr, args.opt);
 
@@ -1988,6 +2034,12 @@ private:
         }
        #endif
 
+        if (matches ("hasCockosExtensions"))
+            return (int32) 0xbeef0000;
+
+        if (auto callbackHandler = dynamic_cast<VSTCallbackHandler*> (processor))
+            return callbackHandler->handleVstPluginCanDo (args.index, args.value, args.ptr, args.opt);
+
         return 0;
     }
 
@@ -2075,7 +2127,7 @@ private:
                     ed->setScaleFactor (editorScaleFactor);
 
                 if (editorComp != nullptr)
-                    editorComp->updateWindowSize();
+                    editorComp->updateWindowSize (true);
             }
            #endif
         }
@@ -2083,6 +2135,26 @@ private:
         return 1;
     }
 
+    pointer_sized_int handleCockosGetParameterText (pointer_sized_int paramIndex,
+                                                    void* dest,
+                                                    float value)
+    {
+        if (processor != nullptr && dest != nullptr)
+        {
+            if (auto* param = juceParameters.getParamForIndex ((int) paramIndex))
+            {
+                if (! LegacyAudioParameter::isLegacy (param))
+                {
+                    String text (param->getText (value, 1024));
+                    memcpy (dest, text.toRawUTF8(), ((size_t) text.length()) + 1);
+                    return 0xbeef;
+                }
+            }
+        }
+
+        return 0;
+    }
+
     //==============================================================================
     pointer_sized_int handleGetNumMidiInputChannels()
     {
