@@ -32,6 +32,8 @@
 namespace juce
 {
 
+#ifndef DOXYGEN
+
 struct AudioUnitHelpers
 {
     class ChannelRemapper
@@ -530,4 +532,6 @@ struct AudioUnitHelpers
     }
 };
 
+#endif // ! DOXYGEN
+
 } // namespace juce
