@@ -48,6 +48,10 @@ const int32 juceVstInterfaceVersion = 2400;
 const int32 juceVstInterfaceIdentifier = 0x56737450;    // The "magic" identifier in the SDK is 'VstP'.
 
 //==============================================================================
+/** Structure used for VSTs
+
+    @tags{Audio}
+*/
 struct VstEffectInterface
 {
     int32 interfaceIdentifier;
@@ -221,6 +225,10 @@ enum VstPlugInCategory
 };
 
 //==============================================================================
+/** Structure used for VSTs
+
+    @tags{Audio}
+*/
 struct VstEditorBounds
 {
     int16 upper;
@@ -241,6 +249,10 @@ enum VstMaxStringLengths
 };
 
 //==============================================================================
+/** Structure used for VSTs
+
+    @tags{Audio}
+*/
 struct VstPinInfo
 {
     char text[vstMaxParameterOrPinLabelLength];
@@ -258,6 +270,10 @@ enum VstPinInfoFlags
 };
 
 //==============================================================================
+/** Structure used for VSTs
+
+    @tags{Audio}
+*/
 struct VstEvent
 {
     int32 type;
@@ -273,6 +289,10 @@ enum VstEventTypes
     vstSysExEventType = 6
 };
 
+/** Structure used for VSTs
+
+    @tags{Audio}
+*/
 struct VstEventBlock
 {
     int32 numberOfEvents;
@@ -280,6 +300,10 @@ struct VstEventBlock
     VstEvent* events[2];
 };
 
+/** Structure used for VSTs
+
+    @tags{Audio}
+*/
 struct VstMidiEvent
 {
     int32 type;
@@ -300,6 +324,10 @@ enum VstMidiEventFlags
     vstMidiEventIsRealtime = 1
 };
 
+/** Structure used for VSTs
+
+    @tags{Audio}
+*/
 struct VstSysExEvent
 {
     int32 type;
@@ -313,6 +341,10 @@ struct VstSysExEvent
 };
 
 //==============================================================================
+/** Structure used for VSTs
+
+    @tags{Audio}
+*/
 struct VstTimingInformation
 {
     double samplePosition;
@@ -369,6 +401,10 @@ enum VstSmpteRates
 };
 
 //==============================================================================
+/** Structure used for VSTs
+
+    @tags{Audio}
+*/
 struct VstIndividualSpeakerInfo
 {
     float azimuthalAngle;
@@ -406,6 +442,10 @@ enum VstIndividualSpeakerType
     vstIndividualSpeakerTypeLFE2
 };
 
+/** Structure used for VSTs
+
+    @tags{Audio}
+*/
 struct VstSpeakerConfiguration
 {
     int32 type;
@@ -461,6 +501,10 @@ enum PresonusExtensionConstants
 };
 
 //==============================================================================
+/** Structure used for VSTs
+
+    @tags{Audio}
+*/
 struct vst2FxBank
 {
     int32 magic1;
