@@ -38,17 +38,19 @@ struct AudioProcessorValueTreeState::Parameter   : public AudioProcessorParamete
                bool meta,
                bool automatable,
                bool discrete,
-               AudioProcessorParameter::Category category)
+               AudioProcessorParameter::Category category,
+               bool boolean)
         : AudioProcessorParameterWithID (parameterID, paramName, labelText, category),
           owner (s), valueToTextFunction (valueToText), textToValueFunction (textToValue),
           range (r), value (defaultVal), defaultValue (defaultVal),
           listenersNeedCalling (true),
           isMetaParam (meta),
           isAutomatableParam (automatable),
-          isDiscreteParam (discrete)
+          isDiscreteParam (discrete),
+          isBooleanParam (boolean)
     {
+        value = defaultValue;
         state.addListener (this);
-        needsUpdate.set (1);
     }
 
     ~Parameter()
@@ -91,7 +93,7 @@ struct AudioProcessorValueTreeState::Parameter   : public AudioProcessorParamete
             listeners.call ([=] (AudioProcessorValueTreeState::Listener& l) { l.parameterChanged (paramID, value); });
             listenersNeedCalling = false;
 
-            needsUpdate.set (1);
+            needsUpdate = true;
         }
     }
 
@@ -117,12 +119,25 @@ struct AudioProcessorValueTreeState::Parameter   : public AudioProcessorParamete
 
     void copyValueToValueTree()
     {
-        if (state.isValid())
-            state.setPropertyExcludingListener (this, owner.valuePropertyID, value, owner.undoManager);
+        if (auto* valueProperty = state.getPropertyPointer (owner.valuePropertyID))
+        {
+            if ((float) *valueProperty != value)
+            {
+                ScopedValueSetter<bool> svs (ignoreParameterChangedCallbacks, true);
+                state.setProperty (owner.valuePropertyID, value, owner.undoManager);
+            }
+        }
+        else
+        {
+            state.setProperty (owner.valuePropertyID, value, nullptr);
+        }
     }
 
     void valueTreePropertyChanged (ValueTree&, const Identifier& property) override
     {
+        if (ignoreParameterChangedCallbacks)
+            return;
+
         if (property == owner.valuePropertyID)
             updateFromValueTree();
     }
@@ -152,6 +167,7 @@ struct AudioProcessorValueTreeState::Parameter   : public AudioProcessorParamete
     bool isMetaParameter() const override      { return isMetaParam; }
     bool isAutomatable() const override        { return isAutomatableParam; }
     bool isDiscrete() const override           { return isDiscreteParam; }
+    bool isBoolean() const override            { return isBooleanParam; }
 
     AudioProcessorValueTreeState& owner;
     ValueTree state;
@@ -160,9 +176,10 @@ struct AudioProcessorValueTreeState::Parameter   : public AudioProcessorParamete
     std::function<float (const String&)> textToValueFunction;
     NormalisableRange<float> range;
     float value, defaultValue;
-    Atomic<int> needsUpdate;
+    std::atomic<bool> needsUpdate { true };
     bool listenersNeedCalling;
-    const bool isMetaParam, isAutomatableParam, isDiscreteParam;
+    const bool isMetaParam, isAutomatableParam, isDiscreteParam, isBooleanParam;
+    bool ignoreParameterChangedCallbacks = false;
 
     JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (Parameter)
 };
@@ -184,7 +201,8 @@ AudioProcessorParameterWithID* AudioProcessorValueTreeState::createAndAddParamet
                                                                                     bool isMetaParameter,
                                                                                     bool isAutomatableParameter,
                                                                                     bool isDiscreteParameter,
-                                                                                    AudioProcessorParameter::Category category)
+                                                                                    AudioProcessorParameter::Category category,
+                                                                                    bool isBooleanParameter)
 {
     // All parameters must be created before giving this manager a ValueTree state!
     jassert (! state.isValid());
@@ -192,7 +210,7 @@ AudioProcessorParameterWithID* AudioProcessorValueTreeState::createAndAddParamet
     Parameter* p = new Parameter (*this, paramID, paramName, labelText, r,
                                   defaultVal, valueToTextFunction, textToValueFunction,
                                   isMetaParameter, isAutomatableParameter,
-                                  isDiscreteParameter, category);
+                                  isDiscreteParameter, category, isBooleanParameter);
     processor.addParameter (p);
     return p;
 }
@@ -214,7 +232,7 @@ Value AudioProcessorValueTreeState::getParameterAsValue (StringRef paramID) cons
     if (Parameter* p = Parameter::getParameterForID (processor, paramID))
         return p->state.getPropertyAsValue (valuePropertyID, undoManager);
 
-    return Value();
+    return {};
 }
 
 NormalisableRange<float> AudioProcessorValueTreeState::getParameterRange (StringRef paramID) const noexcept
@@ -242,6 +260,8 @@ ValueTree AudioProcessorValueTreeState::copyState()
 {
     ScopedLock lock (valueTreeChanging);
 
+    flushParameterValuesToValueTree();
+
     return state.createCopy();
 }
 
@@ -250,6 +270,9 @@ void AudioProcessorValueTreeState::replaceState (const ValueTree& newState)
     ScopedLock lock (valueTreeChanging);
 
     state = newState;
+
+    if (undoManager != nullptr)
+        undoManager->clearUndoHistory();
 }
 
 ValueTree AudioProcessorValueTreeState::getOrCreateChildValueTree (const String& paramID)
@@ -259,8 +282,8 @@ ValueTree AudioProcessorValueTreeState::getOrCreateChildValueTree (const String&
     if (! v.isValid())
     {
         v = ValueTree (valueType);
-        v.setProperty (idPropertyID, paramID, undoManager);
-        state.appendChild (v, undoManager);
+        v.setProperty (idPropertyID, paramID, nullptr);
+        state.appendChild (v, nullptr);
     }
 
     return v;
@@ -312,14 +335,16 @@ bool AudioProcessorValueTreeState::flushParameterValuesToValueTree()
 {
     ScopedLock lock (valueTreeChanging);
 
-    auto anythingUpdated = false;
+    bool anythingUpdated = false;
 
     for (auto* ap : processor.getParameters())
     {
         jassert (dynamic_cast<Parameter*> (ap) != nullptr);
         auto* p = static_cast<Parameter*> (ap);
 
-        if (p->needsUpdate.compareAndSetBool (0, 1))
+        bool needsUpdateTestValue = true;
+
+        if (p->needsUpdate.compare_exchange_strong (needsUpdateTestValue, false))
         {
             p->copyValueToValueTree();
             anythingUpdated = true;
@@ -391,7 +416,12 @@ struct AttachedControlBase  : public AudioProcessorValueTreeState::Listener,
     void beginParameterChange()
     {
         if (AudioProcessorParameter* p = state.getParameter (paramID))
+        {
+            if (state.undoManager != nullptr)
+                state.undoManager->beginNewTransaction();
+
             p->beginChangeGesture();
+        }
     }
 
     void endParameterChange()
@@ -421,12 +451,58 @@ struct AudioProcessorValueTreeState::SliderAttachment::Pimpl  : private Attached
     Pimpl (AudioProcessorValueTreeState& s, const String& p, Slider& sl)
         : AttachedControlBase (s, p), slider (sl), ignoreCallbacks (false)
     {
-        NormalisableRange<float> range (s.getParameterRange (paramID));
-        slider.setRange (range.start, range.end, range.interval);
-        slider.setSkewFactor (range.skew, range.symmetricSkew);
+        NormalisableRange<float> range (state.getParameterRange (paramID));
+
+        if (range.interval != 0 || range.skew != 0)
+        {
+            slider.setRange (range.start, range.end, range.interval);
+            slider.setSkewFactor (range.skew, range.symmetricSkew);
+        }
+        else
+        {
+            auto convertFrom0To1Function = [range] (double currentRangeStart,
+                                                    double currentRangeEnd,
+                                                    double normalisedValue) mutable
+            {
+                range.start = (float) currentRangeStart;
+                range.end = (float) currentRangeEnd;
+                return (double) range.convertFrom0to1 ((float) normalisedValue);
+            };
+
+            auto convertTo0To1Function = [range] (double currentRangeStart,
+                                                  double currentRangeEnd,
+                                                  double mappedValue) mutable
+            {
+                range.start = (float) currentRangeStart;
+                range.end = (float) currentRangeEnd;
+                return (double) range.convertTo0to1 ((float) mappedValue);
+            };
+
+            auto snapToLegalValueFunction = [range] (double currentRangeStart,
+                                                     double currentRangeEnd,
+                                                     double valueToSnap) mutable
+            {
+                range.start = (float) currentRangeStart;
+                range.end = (float) currentRangeEnd;
+                return (double) range.snapToLegalValue ((float) valueToSnap);
+            };
+
+            slider.setNormalisableRange ({ (double) range.start, (double) range.end,
+                                           convertFrom0To1Function,
+                                           convertTo0To1Function,
+                                           snapToLegalValueFunction });
+        }
+
+        if (auto* param = dynamic_cast<AudioProcessorValueTreeState::Parameter*> (state.getParameter (paramID)))
+        {
+            if (param->textToValueFunction != nullptr)
+                slider.valueFromTextFunction = [param] (const String& text) { return (double) param->textToValueFunction (text); };
+
+            if (param->valueToTextFunction != nullptr)
+                slider.textFromValueFunction = [param] (double value)       { return param->valueToTextFunction ((float) value); };
 
-        if (AudioProcessorParameter* param = state.getParameter (paramID))
             slider.setDoubleClickReturnValue (true, range.convertFrom0to1 (param->getDefaultValue()));
+        }
 
         sendInitialUpdate();
         slider.addListener (this);
@@ -452,7 +528,7 @@ struct AudioProcessorValueTreeState::SliderAttachment::Pimpl  : private Attached
     {
         const ScopedLock selfCallbackLock (selfCallbackMutex);
 
-        if ((! ignoreCallbacks) && (! ModifierKeys::getCurrentModifiers().isRightButtonDown()))
+        if ((! ignoreCallbacks) && (! ModifierKeys::currentModifiers.isRightButtonDown()))
             setNewUnnormalisedValue ((float) s->getValue());
     }
 
