@@ -42,6 +42,8 @@ namespace juce
     To use:
     1) Create an AudioProcessorValueTreeState, and give it some parameters using createAndAddParameter().
     2) Initialise the state member variable with a type name.
+
+    @tags{Audio}
 */
 class JUCE_API  AudioProcessorValueTreeState  : private Timer,
                                                 private ValueTree::Listener
@@ -82,6 +84,9 @@ public:
                                         @see AudioProcessorParameter::isDiscrete
         @param category                 Which category the parameter should use.
                                         @see AudioProcessorParameter::Category
+        @param isBoolean                Set this value to true to make this parameter appear as a boolean toggle in
+                                        a hosts view of your plug-ins parameters
+                                        @see AudioProcessorParameter::isBoolean
 
         @returns the parameter object that was created
     */
@@ -96,7 +101,8 @@ public:
                                                           bool isAutomatableParameter = true,
                                                           bool isDiscrete = false,
                                                           AudioProcessorParameter::Category category
-                                                             = AudioProcessorParameter::genericParameter);
+                                                             = AudioProcessorParameter::genericParameter,
+                                                          bool isBoolean = false);
 
     /** Returns a parameter by its ID string. */
     AudioProcessorParameterWithID* getParameter (StringRef parameterID) const noexcept;
@@ -192,7 +198,7 @@ public:
     private:
         struct Pimpl;
         friend struct ContainerDeletePolicy<Pimpl>;
-        ScopedPointer<Pimpl> pimpl;
+        std::unique_ptr<Pimpl> pimpl;
         JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (SliderAttachment)
     };
 
@@ -216,7 +222,7 @@ public:
     private:
         struct Pimpl;
         friend struct ContainerDeletePolicy<Pimpl>;
-        ScopedPointer<Pimpl> pimpl;
+        std::unique_ptr<Pimpl> pimpl;
         JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (ComboBoxAttachment)
     };
 
@@ -240,7 +246,7 @@ public:
     private:
         struct Pimpl;
         friend struct ContainerDeletePolicy<Pimpl>;
-        ScopedPointer<Pimpl> pimpl;
+        std::unique_ptr<Pimpl> pimpl;
         JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (ButtonAttachment)
     };
 
