@@ -32,6 +32,8 @@ namespace juce
 
 //==============================================================================
 /**
+
+    @tags{Audio}
 */
 class AudioCDBurner     : public ChangeBroadcaster
 {
@@ -161,7 +163,7 @@ private:
 
     class Pimpl;
     friend struct ContainerDeletePolicy<Pimpl>;
-    ScopedPointer<Pimpl> pimpl;
+    std::unique_ptr<Pimpl> pimpl;
 
     JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (AudioCDBurner)
 };
