@@ -23,7 +23,10 @@
 namespace juce
 {
 
-/** Describes a phyiscal connection between two ports of two block devices. */
+/** Describes a phyiscal connection between two ports of two block devices.
+
+    @tags{Blocks}
+*/
 struct BlockDeviceConnection
 {
     Block::UID device1, device2;
@@ -34,7 +37,10 @@ struct BlockDeviceConnection
 };
 
 
-/** Describes a set of blocks and the connections between them. */
+/** Describes a set of blocks and the connections between them.
+
+    @tags{Blocks}
+*/
 struct BlockTopology
 {
     Block::Array blocks;
