@@ -28,6 +28,8 @@ namespace juce
     A simple class to generate hash functions for some primitive types, intended for
     use with the HashMap class.
     @see HashMap
+
+    @tags{Core}
 */
 struct DefaultHashFunctions
 {
@@ -44,7 +46,9 @@ struct DefaultHashFunctions
     /** Generates a simple hash from a variant. */
     static int generateHash (const var& key, int upperLimit) noexcept       { return generateHash (key.toString(), upperLimit); }
     /** Generates a simple hash from a void ptr. */
-    static int generateHash (const void* key, int upperLimit) noexcept      { return generateHash ((pointer_sized_uint) key, upperLimit); }
+    static int generateHash (const void* key, int upperLimit) noexcept      { return generateHash ((uint64) (pointer_sized_uint) key, upperLimit); }
+    /** Generates a simple hash from a UUID. */
+    static int generateHash (const Uuid& key, int upperLimit) noexcept      { return generateHash (key.hash(), upperLimit); }
 };
 
 
@@ -89,6 +93,8 @@ struct DefaultHashFunctions
 
     @tparam HashFunctionType The class of hash function, which must be copy-constructible.
     @see CriticalSection, DefaultHashFunctions, NamedValueSet, SortedSet
+
+    @tags{Core}
 */
 template <typename KeyType,
           typename ValueType,
@@ -97,8 +103,8 @@ template <typename KeyType,
 class HashMap
 {
 private:
-    typedef typename TypeHelpers::ParameterType<KeyType>::type   KeyTypeParameter;
-    typedef typename TypeHelpers::ParameterType<ValueType>::type ValueTypeParameter;
+    using KeyTypeParameter   = typename TypeHelpers::ParameterType<KeyType>::type;
+    using ValueTypeParameter = typename TypeHelpers::ParameterType<ValueType>::type;
 
 public:
     //==============================================================================
@@ -140,7 +146,7 @@ public:
 
             while (h != nullptr)
             {
-                const ScopedPointer<HashEntry> deleter (h);
+                const std::unique_ptr<HashEntry> deleter (h);
                 h = h->nextEntry;
             }
 
@@ -237,7 +243,7 @@ public:
         {
             if (entry->key == keyToRemove)
             {
-                const ScopedPointer<HashEntry> deleter (entry);
+                const std::unique_ptr<HashEntry> deleter (entry);
 
                 entry = entry->nextEntry;
 
@@ -270,7 +276,7 @@ public:
             {
                 if (entry->value == valueToRemove)
                 {
-                    const ScopedPointer<HashEntry> deleter (entry);
+                    const std::unique_ptr<HashEntry> deleter (entry);
 
                     entry = entry->nextEntry;
 
