@@ -435,9 +435,7 @@ var::var() noexcept : type (&VariantType_Void::instance) {}
 var::var (const VariantType& t) noexcept  : type (&t) {}
 var::~var() noexcept  { type->cleanUp (value); }
 
-#if JUCE_ALLOW_STATIC_NULL_VARIABLES
-const var var::null;
-#endif
+JUCE_DECLARE_DEPRECATED_STATIC (const var var::null);
 
 //==============================================================================
 var::var (const var& valueToCopy)  : type (valueToCopy.type)
