@@ -35,6 +35,8 @@ namespace juce
     using writeToStream()/readFromStream(), or as JSON by using the JSON class.
 
     @see JSON, DynamicObject
+
+    @tags{Core}
 */
 class JUCE_API  var
 {
@@ -272,17 +274,15 @@ public:
     */
     static var readFromStream (InputStream& input);
 
-   #if JUCE_ALLOW_STATIC_NULL_VARIABLES
-    /** This was a static empty var object, but is now deprecated as it's too easy to accidentally
-        use it indirectly during a static constructor, leading to hard-to-find order-of-initialisation
-        problems.
-        @deprecated If you need a default-constructed var, just use var() or {}.
-        The only time you might miss having var::null available might be if you need to return an
-        empty var from a function by reference, but if you need to do that, it's easy enough to use
-        a function-local static var and return that, avoiding any order-of-initialisation issues.
+    /* This was a static empty var object, but is now deprecated as it's too easy to accidentally
+       use it indirectly during a static constructor, leading to hard-to-find order-of-initialisation
+       problems.
+       @deprecated If you need a default-constructed var, just use var() or {}.
+       The only time you might miss having var::null available might be if you need to return an
+       empty var from a function by reference, but if you need to do that, it's easy enough to use
+       a function-local static var and return that, avoiding any order-of-initialisation issues.
     */
-    static const var null;
-   #endif
+    JUCE_DEPRECATED_STATIC (static const var null);
 
 private:
     //==============================================================================
@@ -328,7 +328,10 @@ JUCE_API bool operator== (const var&, const char*);
 JUCE_API bool operator!= (const var&, const char*);
 
 //==============================================================================
-/** This template-overloaded class can be used to convert between var and custom types. */
+/** This template-overloaded class can be used to convert between var and custom types.
+
+    @tags{Core}
+*/
 template <typename Type>
 struct VariantConverter
 {
@@ -336,12 +339,13 @@ struct VariantConverter
     static var toVar (const Type& t)               { return t; }
 };
 
-/** This template-overloaded class can be used to convert between var and custom types. */
+#ifndef DOXYGEN
 template <>
 struct VariantConverter<String>
 {
     static String fromVar (const var& v)           { return v.toString(); }
     static var toVar (const String& s)             { return s; }
 };
+#endif
 
 } // namespace juce
