@@ -34,6 +34,8 @@ namespace juce
     output stream.
 
     @see FileInputStream, FileOutputStream
+
+    @tags{Core}
 */
 class JUCE_API  File final
 {
@@ -679,13 +681,15 @@ public:
         It can also write the 'ff fe' unicode header bytes before the text to indicate
         the endianness of the file.
 
-        Any single \\n characters in the string are replaced with \\r\\n before it is written.
+        If lineEndings is nullptr, then line endings in the text won't be modified. If you
+        pass "\\n" or "\\r\\n" then this function will replace any existing line feeds.
 
         @see replaceWithText
     */
     bool appendText (const String& textToAppend,
                      bool asUnicode = false,
-                     bool writeUnicodeHeaderBytes = false) const;
+                     bool writeUnicodeHeaderBytes = false,
+                     const char* lineEndings = "\r\n") const;
 
     /** Replaces this file's contents with a given text string.
 
@@ -705,7 +709,8 @@ public:
     */
     bool replaceWithText (const String& textToWrite,
                           bool asUnicode = false,
-                          bool writeUnicodeHeaderBytes = false) const;
+                          bool writeUnicodeHeaderBytes = false,
+                          const char* lineEndings = "\r\n") const;
 
     /** Attempts to scan the contents of this file and compare it to another file, returning
         true if this is possible and they match byte-for-byte.
@@ -985,12 +990,27 @@ public:
     */
     File getLinkedTarget() const;
 
+    /** Create a symbolic link to a native path and return a boolean to indicate success.
+
+        Use this method if you want to create a link to a relative path or a special native
+        file path (such as a device file on Windows).
+    */
+    static bool createSymbolicLink (const File& linkFileToCreate,
+                                    const String& nativePathOfTarget,
+                                    bool overwriteExisting);
+
+    /** This returns the native path that the symbolic link points to. The returned path
+        is a native path of the current OS and can be a relative, absolute or special path. */
+    String getNativeLinkedTarget() const;
+
    #if JUCE_WINDOWS || DOXYGEN
     /** Windows ONLY - Creates a win32 .LNK shortcut file that links to this file. */
     bool createShortcut (const String& description, const File& linkFileToCreate) const;
 
     /** Windows ONLY - Returns true if this is a win32 .LNK file. */
     bool isShortcut() const;
+   #else
+
    #endif
 
     //==============================================================================
@@ -1008,6 +1028,7 @@ public:
    #endif
 
     //==============================================================================
+    /** Comparator for files */
     struct NaturalFileComparator
     {
         NaturalFileComparator (bool shouldPutFoldersFirst) noexcept : foldersFirst (shouldPutFoldersFirst) {}
@@ -1027,21 +1048,14 @@ public:
         bool foldersFirst;
     };
 
-   #if (! defined(DOXYGEN)) && (! defined (JUCE_GCC))
-    // Deprecated: use File::getSeparatorChar() and File::getSeparatorString() instead!
-    JUCE_DEPRECATED (static const juce_wchar separator);
-    JUCE_DEPRECATED (static const StringRef separatorString);
-   #endif
-
-    //==============================================================================
-   #if JUCE_ALLOW_STATIC_NULL_VARIABLES
-    /** This was a static empty File object, but is now deprecated as it's too easy to accidentally
-        use it indirectly during a static constructor, leading to hard-to-find order-of-initialisation
-        problems.
-        @deprecated If you need a default-constructed File object, just use File() or {}.
+    /* These static objects are deprecated because it's too easy to accidentally use them indirectly
+       during a static constructor, which leads to very obscure order-of-initialisation bugs.
+       Use File::getSeparatorChar() and File::getSeparatorString(), and instead of File::nonexistent,
+       just use File() or {}.
     */
-    static const File nonexistent;
-   #endif
+    JUCE_DEPRECATED_STATIC (static const juce_wchar separator);
+    JUCE_DEPRECATED_STATIC (static const StringRef separatorString);
+    JUCE_DEPRECATED_STATIC (static const File nonexistent);
 
 private:
     //==============================================================================
