@@ -93,7 +93,7 @@ XmlElement* XmlDocument::getDocumentElement (const bool onlyReadOuterDocumentEle
 {
     if (originalText.isEmpty() && inputSource != nullptr)
     {
-        ScopedPointer<InputStream> in (inputSource->createInputStream());
+        std::unique_ptr<InputStream> in (inputSource->createInputStream());
 
         if (in != nullptr)
         {
@@ -144,7 +144,7 @@ String XmlDocument::getFileContents (const String& filename) const
 {
     if (inputSource != nullptr)
     {
-        ScopedPointer<InputStream> in (inputSource->createInputStreamFor (filename.trim().unquoted()));
+        std::unique_ptr<InputStream> in (inputSource->createInputStreamFor (filename.trim().unquoted()));
 
         if (in != nullptr)
             return in->readEntireStreamAsString();
@@ -189,7 +189,7 @@ XmlElement* XmlDocument::parseDocumentElement (String::CharPointerType textToPar
     else
     {
         lastError.clear();
-        ScopedPointer<XmlElement> result (readNextElement (! onlyReadOuterDocumentElement));
+        std::unique_ptr<XmlElement> result (readNextElement (! onlyReadOuterDocumentElement));
 
         if (! errorOccurred)
             return result.release();
