@@ -32,6 +32,8 @@ namespace juce
          BufferedInputStream, so that it has to read larger blocks less often.
 
     @see GZIPCompressorOutputStream
+
+    @tags{Core}
 */
 class JUCE_API  GZIPDecompressorInputStream  : public InputStream
 {
@@ -89,7 +91,7 @@ private:
 
     class GZIPDecompressHelper;
     friend struct ContainerDeletePolicy<GZIPDecompressHelper>;
-    ScopedPointer<GZIPDecompressHelper> helper;
+    std::unique_ptr<GZIPDecompressHelper> helper;
 
    #if JUCE_CATCH_DEPRECATED_CODE_MISUSE
     // The arguments to this method have changed! Please pass a Format enum instead of the old dontWrap bool.
