@@ -30,7 +30,7 @@ namespace juce
 class ValueTree::SharedObject  : public ReferenceCountedObject
 {
 public:
-    typedef ReferenceCountedObjectPtr<SharedObject> Ptr;
+    using Ptr = ReferenceCountedObjectPtr<SharedObject>;
 
     explicit SharedObject (const Identifier& t) noexcept  : type (t) {}
 
@@ -220,7 +220,6 @@ public:
         auto newObject = new SharedObject (typeToMatch);
         addChild (newObject, -1, undoManager);
         return ValueTree (newObject);
-
     }
 
     ValueTree getChildWithProperty (const Identifier& propertyName, const var& propertyValue) const
@@ -580,16 +579,13 @@ ValueTree::ValueTree() noexcept
 {
 }
 
-#if JUCE_ALLOW_STATIC_NULL_VARIABLES
-const ValueTree ValueTree::invalid;
-#endif
+JUCE_DECLARE_DEPRECATED_STATIC (const ValueTree ValueTree::invalid);
 
 ValueTree::ValueTree (const Identifier& type)  : object (new ValueTree::SharedObject (type))
 {
     jassert (type.toString().isNotEmpty()); // All objects must be given a sensible type name!
 }
 
-#if JUCE_COMPILER_SUPPORTS_INITIALIZER_LISTS
 ValueTree::ValueTree (const Identifier& type,
                       std::initializer_list<std::pair<Identifier, var>> properties,
                       std::initializer_list<ValueTree> subTrees)
@@ -601,7 +597,6 @@ ValueTree::ValueTree (const Identifier& type,
     for (auto& tree : subTrees)
         addChild (tree, -1, nullptr);
 }
-#endif
 
 ValueTree::ValueTree (SharedObject* so) noexcept  : object (so)
 {
@@ -639,11 +634,13 @@ ValueTree& ValueTree::operator= (const ValueTree& other)
 ValueTree::ValueTree (ValueTree&& other) noexcept
     : object (static_cast<SharedObject::Ptr&&> (other.object))
 {
+    if (object != nullptr)
+        object->valueTreesWithListeners.removeValue (&other);
 }
 
 ValueTree::~ValueTree()
 {
-    if (listeners.size() > 0 && object != nullptr)
+    if (! listeners.isEmpty() && object != nullptr)
         object->valueTreesWithListeners.removeValue (this);
 }
 
@@ -996,7 +993,7 @@ ValueTree ValueTree::fromXml (const XmlElement& xml)
 
 String ValueTree::toXmlString() const
 {
-    ScopedPointer<XmlElement> xml (createXml());
+    std::unique_ptr<XmlElement> xml (createXml());
 
     if (xml != nullptr)
         return xml->createDocument ({});
@@ -1156,8 +1153,8 @@ public:
             }
             expect (v1.isEquivalentTo (ValueTree::readFromGZIPData (zipped.getData(), zipped.getDataSize())));
 
-            ScopedPointer<XmlElement> xml1 (v1.createXml());
-            ScopedPointer<XmlElement> xml2 (v2.createCopy().createXml());
+            std::unique_ptr<XmlElement> xml1 (v1.createXml());
+            std::unique_ptr<XmlElement> xml2 (v2.createCopy().createXml());
             expect (xml1->isEquivalentTo (xml2.get(), false));
 
             auto v4 = v2.createCopy();
