@@ -66,6 +66,8 @@ namespace juce
     sub-trees are added or removed.
 
     @see var, XmlElement
+
+    @tags{DataStructures}
 */
 class JUCE_API  ValueTree  final
 {
@@ -86,7 +88,6 @@ public:
     */
     explicit ValueTree (const Identifier& type);
 
-   #if JUCE_COMPILER_SUPPORTS_INITIALIZER_LISTS
     /** Creates a value tree from nested lists of properties and ValueTrees.
 
         This code,
@@ -129,7 +130,6 @@ public:
     ValueTree (const Identifier& type,
                std::initializer_list<std::pair<Identifier, var>> properties,
                std::initializer_list<ValueTree> subTrees = {});
-   #endif
 
     /** Creates a reference to another ValueTree. */
     ValueTree (const ValueTree&) noexcept;
@@ -589,12 +589,10 @@ public:
     */
     int getReferenceCount() const noexcept;
 
-   #if JUCE_ALLOW_STATIC_NULL_VARIABLES
-    /** An invalid ValueTree that can be used if you need to return one as an error condition, etc.
+    /* An invalid ValueTree that can be used if you need to return one as an error condition, etc.
         @deprecated If you need an empty ValueTree object, just use ValueTree() or {}.
     */
-    static const ValueTree invalid;
-   #endif
+    JUCE_DEPRECATED_STATIC (static const ValueTree invalid);
 
 private:
     //==============================================================================
