@@ -31,37 +31,78 @@ namespace dsp
 
 namespace SIMDRegister_test_internal
 {
-    template <typename type>
-    static void fillRandom (type* dst, const int size, Random& random)
-    {
-        bool is_signed = std::is_signed<type>::value;
-
-        for (int i = 0; i < size; ++i)
-        {
-            if (is_signed)
-            {
-                *dst++ = static_cast<type> ((random.nextFloat() * 16.0) - 8.0);
-            }
-            else
-            {
-                *dst++ = static_cast<type> (random.nextFloat() * 8.0);
-            }
-        }
-    }
+    template <typename type, typename = void> struct RandomPrimitive {};
 
     template <typename type>
-    static void fillRandom (std::complex<type>* dst, const int size, Random& random)
+    struct RandomPrimitive<type, typename std::enable_if<std::is_floating_point<type>::value>::type>
     {
-        for (int i = 0; i < size; ++i)
+        static type next (Random& random)
         {
-            type real, imag;
+            return static_cast<type> (std::is_signed<type>::value ? (random.nextFloat() * 16.0) - 8.0
+                                                                  : (random.nextFloat() * 8.0));
 
-            real = static_cast<type> ((random.nextFloat() * 16.0) - 8.0);
-            imag = static_cast<type> ((random.nextFloat() * 16.0) - 8.0);
-
-            *dst++ = std::complex<type> (real, imag);
         }
-    }
+    };
+
+    template <typename type>
+    struct RandomPrimitive<type, typename std::enable_if<std::is_integral<type>::value>::type>
+    {
+        static type next (Random& random)
+        {
+            return static_cast<type> (random.nextInt64());
+
+        }
+    };
+
+    template <typename type> struct RandomValue { static type next (Random& random) { return RandomPrimitive<type>::next (random); } };
+    template <typename type>
+    struct RandomValue<std::complex<type>>
+    {
+        static std::complex<type> next (Random& random)
+        {
+            return {RandomPrimitive<type>::next (random), RandomPrimitive<type>::next (random)};
+        }
+    };
+
+
+    template <typename type>
+    struct VecFiller
+    {
+        static void fill (type* dst, const int size, Random& random)
+        {
+            for (int i = 0; i < size; ++i)
+                dst[i] = RandomValue<type>::next (random);
+        }
+    };
+
+    // We need to specialise for complex types: otherwise GCC 6 gives
+    // us an ICE internal compiler error after which the compiler seg faults.
+    template <typename type>
+    struct VecFiller<std::complex<type>>
+    {
+        static void fill (std::complex<type>* dst, const int size, Random& random)
+        {
+            for (int i = 0; i < size; ++i)
+                dst[i] = std::complex<type> (RandomValue<type>::next (random), RandomValue<type>::next (random));
+        }
+    };
+
+    template <typename type>
+    struct VecFiller<SIMDRegister<type>>
+    {
+        static SIMDRegister<type> fill(Random& random)
+        {
+            constexpr int size = (int) SIMDRegister<type>::SIMDNumElements;
+           #ifdef _MSC_VER
+            __declspec(align(sizeof (SIMDRegister<type>))) type elements[size];
+           #else
+            type elements[size] __attribute__((aligned(sizeof (SIMDRegister<type>))));
+           #endif
+
+            VecFiller<type>::fill (elements, size, random);
+            return SIMDRegister<type>::fromRawArray (elements);
+        }
+    };
 
     // Avoid visual studio warning
     template <typename type>
@@ -102,10 +143,17 @@ public:
     template <typename type>
     static bool allValuesEqualTo (const SIMDRegister<type>& vec, const type scalar)
     {
+       #ifdef _MSC_VER
+        __declspec(align(sizeof (SIMDRegister<type>))) type elements[SIMDRegister<type>::SIMDNumElements];
+       #else
+        type elements[SIMDRegister<type>::SIMDNumElements] __attribute__((aligned(sizeof (SIMDRegister<type>))));
+       #endif
+
+        vec.copyToRawArray (elements);
+
         // as we do not want to rely on the access operator we cast this to a primitive pointer
-        const type* ptr = reinterpret_cast<const type*> (&vec);
         for (size_t i = 0; i < SIMDRegister<type>::SIMDNumElements; ++i)
-            if (ptr[i] != scalar) return false;
+            if (elements[i] != scalar) return false;
 
         return true;
     }
@@ -246,12 +294,20 @@ public:
             u.expect (allValuesEqualTo<type> (SIMDRegister<type>::expand (static_cast<type> (23)), 23));
 
             {
-                SIMDRegister<type> a;
+               #ifdef _MSC_VER
+                __declspec(align(sizeof (SIMDRegister<type>))) type elements[SIMDRegister<type>::SIMDNumElements];
+               #else
+                type elements[SIMDRegister<type>::SIMDNumElements] __attribute__((aligned(sizeof (SIMDRegister<type>))));
+               #endif
+                SIMDRegister_test_internal::VecFiller<type>::fill (elements, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister<type> a (SIMDRegister<type>::fromRawArray (elements));
 
-                type* ptr = reinterpret_cast<type*>(&a);
-                SIMDRegister_test_internal::fillRandom (ptr, SIMDRegister<type>::SIMDNumElements, random);
+                u.expect (vecEqualToArray (a, elements));
 
-                u.expect (vecEqualToArray (SIMDRegister<type> (a), ptr));
+                SIMDRegister<type> b (a);
+                a *= static_cast<type> (2);
+
+                u.expect (vecEqualToArray (b, elements));
             }
         }
     };
@@ -265,7 +321,7 @@ public:
             SIMDRegister<type> a;
             type array [SIMDRegister<type>::SIMDNumElements];
 
-            SIMDRegister_test_internal::fillRandom (array, SIMDRegister<type>::SIMDNumElements, random);
+            SIMDRegister_test_internal::VecFiller<type>::fill (array, SIMDRegister<type>::SIMDNumElements, random);
 
             // Test non-const access operator
             for (size_t i = 0; i < SIMDRegister<type>::SIMDNumElements; ++i)
@@ -290,14 +346,17 @@ public:
             for (int n = 0; n < 100; ++n)
             {
                 // set-up
-                SIMDRegister<type> a, b, c;
+                SIMDRegister<type> a (static_cast<type> (0));
+                SIMDRegister<type> b (static_cast<type> (0));
+                SIMDRegister<type> c (static_cast<type> (0));
+
                 type array_a [SIMDRegister<type>::SIMDNumElements];
                 type array_b [SIMDRegister<type>::SIMDNumElements];
                 type array_c [SIMDRegister<type>::SIMDNumElements];
 
-                SIMDRegister_test_internal::fillRandom (array_a, SIMDRegister<type>::SIMDNumElements, random);
-                SIMDRegister_test_internal::fillRandom (array_b, SIMDRegister<type>::SIMDNumElements, random);
-                SIMDRegister_test_internal::fillRandom (array_c, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (array_a, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (array_b, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (array_c, SIMDRegister<type>::SIMDNumElements, random);
 
                 copy (a, array_a); copy (b, array_b); copy (c, array_c);
 
@@ -310,9 +369,9 @@ public:
                 u.expect (vecEqualToArray (a, array_a));
                 u.expect (vecEqualToArray (b, array_b));
 
-                SIMDRegister_test_internal::fillRandom (array_a, SIMDRegister<type>::SIMDNumElements, random);
-                SIMDRegister_test_internal::fillRandom (array_b, SIMDRegister<type>::SIMDNumElements, random);
-                SIMDRegister_test_internal::fillRandom (array_c, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (array_a, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (array_b, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (array_c, SIMDRegister<type>::SIMDNumElements, random);
 
                 copy (a, array_a); copy (b, array_b); copy (c, array_c);
 
@@ -326,9 +385,9 @@ public:
                 u.expect (vecEqualToArray (b, array_b));
 
                 // set-up again
-                SIMDRegister_test_internal::fillRandom (array_a, SIMDRegister<type>::SIMDNumElements, random);
-                SIMDRegister_test_internal::fillRandom (array_b, SIMDRegister<type>::SIMDNumElements, random);
-                SIMDRegister_test_internal::fillRandom (array_c, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (array_a, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (array_b, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (array_c, SIMDRegister<type>::SIMDNumElements, random);
                 copy (a, array_a); copy (b, array_b); copy (c, array_c);
 
                 // test out-of-place with both params being vectors
@@ -363,7 +422,6 @@ public:
             typedef typename SIMDRegister<type>::vMaskType vMaskType;
             typedef typename SIMDRegister<type>::MaskType MaskType;
 
-
             for (int n = 0; n < 100; ++n)
             {
                 // Check flip sign bit and using as a union
@@ -372,21 +430,28 @@ public:
 
                     union ConversionUnion
                     {
-                        inline ConversionUnion() {}
+                        inline ConversionUnion() : floatVersion (static_cast<type> (0)) {}
                         inline ~ConversionUnion() {}
                         SIMDRegister<type> floatVersion;
                         vMaskType intVersion;
                     } a, b;
 
                     vMaskType bitmask = vMaskType::expand (static_cast<MaskType> (1) << (sizeof (MaskType) - 1));
-                    SIMDRegister_test_internal::fillRandom (array_a, SIMDRegister<type>::SIMDNumElements, random);
+                    SIMDRegister_test_internal::VecFiller<type>::fill (array_a, SIMDRegister<type>::SIMDNumElements, random);
                     copy (a.floatVersion, array_a);
                     copy (b.floatVersion, array_a);
 
                     Operation::template inplace<SIMDRegister<type>, vMaskType> (a.floatVersion, bitmask);
                     Operation::template inplace<vMaskType, vMaskType> (b.intVersion, bitmask);
 
-                    u.expect (vecEqualToArray (a.floatVersion, reinterpret_cast<const type*> (&b.floatVersion)));
+                   #ifdef _MSC_VER
+                    __declspec(align(sizeof (SIMDRegister<type>))) type elements[SIMDRegister<type>::SIMDNumElements];
+                   #else
+                    type elements[SIMDRegister<type>::SIMDNumElements] __attribute__((aligned(sizeof (SIMDRegister<type>))));
+                   #endif
+                    b.floatVersion.copyToRawArray (elements);
+
+                    u.expect (vecEqualToArray (a.floatVersion, elements));
                 }
 
                 // set-up
@@ -397,42 +462,51 @@ public:
                 MaskType array_b [SIMDRegister<MaskType>::SIMDNumElements];
                 MaskType array_c [SIMDRegister<MaskType>::SIMDNumElements];
 
-                type* conv_a = reinterpret_cast<type*> (array_a);
-                type* conv_c = reinterpret_cast<type*> (array_c);
+                type float_a [SIMDRegister<type>::SIMDNumElements];
+                type float_c [SIMDRegister<type>::SIMDNumElements];
 
-                SIMDRegister_test_internal::fillRandom (conv_a, SIMDRegister<type>::SIMDNumElements, random);
-                SIMDRegister_test_internal::fillRandom (array_b, SIMDRegister<MaskType>::SIMDNumElements, random);
-                SIMDRegister_test_internal::fillRandom (conv_c, SIMDRegister<type>::SIMDNumElements, random);
-                copy (a, conv_a); copy (b, array_b); copy (c, conv_c);
+                SIMDRegister_test_internal::VecFiller<type>::fill (float_a, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<MaskType>::fill (array_b, SIMDRegister<MaskType>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (float_c, SIMDRegister<type>::SIMDNumElements, random);
+
+                memcpy (array_a, float_a, sizeof (type) * SIMDRegister<type>::SIMDNumElements);
+                memcpy (array_c, float_c, sizeof (type) * SIMDRegister<type>::SIMDNumElements);
+                copy (a, float_a); copy (b, array_b); copy (c, float_c);
 
                 // test in-place with both params being vectors
                 for (size_t i = 0; i < SIMDRegister<MaskType>::SIMDNumElements; ++i)
                     Operation::template inplace<MaskType, MaskType> (array_a[i], array_b[i]);
+                memcpy (float_a, array_a, sizeof (type) * SIMDRegister<type>::SIMDNumElements);
 
                 Operation::template inplace<SIMDRegister<type>, vMaskType> (a, b);
 
-                u.expect (vecEqualToArray (a, conv_a));
+                u.expect (vecEqualToArray (a, float_a));
                 u.expect (vecEqualToArray (b, array_b));
 
-                SIMDRegister_test_internal::fillRandom (conv_a, SIMDRegister<type>::SIMDNumElements, random);
-                SIMDRegister_test_internal::fillRandom (array_b, SIMDRegister<MaskType>::SIMDNumElements, random);
-                SIMDRegister_test_internal::fillRandom (conv_c, SIMDRegister<type>::SIMDNumElements, random);
-                copy (a, conv_a); copy (b, array_b); copy (c, conv_c);
+                SIMDRegister_test_internal::VecFiller<type>::fill (float_a, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<MaskType>::fill (array_b, SIMDRegister<MaskType>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (float_c, SIMDRegister<type>::SIMDNumElements, random);
+                memcpy (array_a, float_a, sizeof (type) * SIMDRegister<type>::SIMDNumElements);
+                memcpy (array_c, float_c, sizeof (type) * SIMDRegister<type>::SIMDNumElements);
+                copy (a, float_a); copy (b, array_b); copy (c, float_c);
 
                 // test in-place with one param being scalar
                 for (size_t i = 0; i < SIMDRegister<MaskType>::SIMDNumElements; ++i)
                     Operation::template inplace<MaskType, MaskType> (array_a[i], static_cast<MaskType> (9));
+                memcpy (float_a, array_a, sizeof (type) * SIMDRegister<type>::SIMDNumElements);
 
                 Operation::template inplace<SIMDRegister<type>, MaskType> (a, static_cast<MaskType> (9));
 
-                u.expect (vecEqualToArray (a, conv_a));
+                u.expect (vecEqualToArray (a, float_a));
                 u.expect (vecEqualToArray (b, array_b));
 
                 // set-up again
-                SIMDRegister_test_internal::fillRandom (conv_a, SIMDRegister<type>::SIMDNumElements, random);
-                SIMDRegister_test_internal::fillRandom (array_b, SIMDRegister<MaskType>::SIMDNumElements, random);
-                SIMDRegister_test_internal::fillRandom (conv_c, SIMDRegister<type>::SIMDNumElements, random);
-                copy (a, conv_a); copy (b, array_b); copy (c, conv_c);
+                SIMDRegister_test_internal::VecFiller<type>::fill (float_a, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<MaskType>::fill (array_b, SIMDRegister<MaskType>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (float_c, SIMDRegister<type>::SIMDNumElements, random);
+                memcpy (array_a, float_a, sizeof (type) * SIMDRegister<type>::SIMDNumElements);
+                memcpy (array_c, float_c, sizeof (type) * SIMDRegister<type>::SIMDNumElements);
+                copy (a, float_a); copy (b, array_b); copy (c, float_c);
 
                 // test out-of-place with both params being vectors
                 for (size_t i = 0; i < SIMDRegister<MaskType>::SIMDNumElements; ++i)
@@ -440,22 +514,26 @@ public:
                     array_c[i] =
                         Operation::template outofplace<MaskType, MaskType> (array_a[i], array_b[i]);
                 }
+                memcpy (float_a, array_a, sizeof (type) * SIMDRegister<type>::SIMDNumElements);
+                memcpy (float_c, array_c, sizeof (type) * SIMDRegister<type>::SIMDNumElements);
 
                 c = Operation::template outofplace<SIMDRegister<type>, vMaskType> (a, b);
 
-                u.expect (vecEqualToArray (a, conv_a));
+                u.expect (vecEqualToArray (a, float_a));
                 u.expect (vecEqualToArray (b, array_b));
-                u.expect (vecEqualToArray (c, conv_c));
+                u.expect (vecEqualToArray (c, float_c));
 
                 // test out-of-place with one param being scalar
                 for (size_t i = 0; i < SIMDRegister<MaskType>::SIMDNumElements; ++i)
                     array_c[i] = Operation::template outofplace<MaskType, MaskType> (array_a[i], static_cast<MaskType> (9));
+                memcpy (float_a, array_a, sizeof (type) * SIMDRegister<type>::SIMDNumElements);
+                memcpy (float_c, array_c, sizeof (type) * SIMDRegister<type>::SIMDNumElements);
 
                 c = Operation::template outofplace<SIMDRegister<type>, MaskType> (a, static_cast<MaskType> (9));
 
-                u.expect (vecEqualToArray (a, conv_a));
+                u.expect (vecEqualToArray (a, float_a));
                 u.expect (vecEqualToArray (b, array_b));
-                u.expect (vecEqualToArray (c, conv_c));
+                u.expect (vecEqualToArray (c, float_c));
             }
         }
     };
@@ -481,8 +559,8 @@ public:
                 MaskType array_ge  [SIMDRegister<type>::SIMDNumElements];
 
 
-                SIMDRegister_test_internal::fillRandom (array_a, SIMDRegister<type>::SIMDNumElements, random);
-                SIMDRegister_test_internal::fillRandom (array_b, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (array_a, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (array_b, SIMDRegister<type>::SIMDNumElements, random);
 
                 // do check
                 for (size_t j = 0; j < SIMDRegister<type>::SIMDNumElements; ++j)
@@ -495,7 +573,9 @@ public:
                     array_ge  [j] = (array_a[j] >= array_b[j]) ? static_cast<MaskType> (-1) : 0;
                 }
 
-                SIMDRegister<type> a, b;
+                SIMDRegister<type> a (static_cast<type> (0));
+                SIMDRegister<type> b (static_cast<type> (0));
+
                 vMaskType eq, neq, lt, le, gt, ge;
 
                 copy (a, array_a);
@@ -517,8 +597,8 @@ public:
 
                 do
                 {
-                    SIMDRegister_test_internal::fillRandom (array_a, SIMDRegister<type>::SIMDNumElements, random);
-                    SIMDRegister_test_internal::fillRandom (array_b, SIMDRegister<type>::SIMDNumElements, random);
+                    SIMDRegister_test_internal::VecFiller<type>::fill (array_a, SIMDRegister<type>::SIMDNumElements, random);
+                    SIMDRegister_test_internal::VecFiller<type>::fill (array_b, SIMDRegister<type>::SIMDNumElements, random);
                 } while (std::equal (array_a, array_a + SIMDRegister<type>::SIMDNumElements, array_b));
 
                 copy (a, array_a);
@@ -528,7 +608,7 @@ public:
                 u.expect (! (a == b));
                 u.expect (! (b == a));
 
-                SIMDRegister_test_internal::fillRandom (array_a, SIMDRegister<type>::SIMDNumElements, random);
+                SIMDRegister_test_internal::VecFiller<type>::fill (array_a, SIMDRegister<type>::SIMDNumElements, random);
                 copy (a, array_a);
                 copy (b, array_a);
 
@@ -537,7 +617,7 @@ public:
                 u.expect (! (a != b));
                 u.expect (! (b != a));
 
-                auto scalar = a[0];
+                type scalar = a[0];
                 a = SIMDRegister<type>::expand (scalar);
 
                 u.expect (a == scalar);
@@ -562,10 +642,10 @@ public:
             type array_c [SIMDRegister<type>::SIMDNumElements];
             type array_d [SIMDRegister<type>::SIMDNumElements];
 
-            SIMDRegister_test_internal::fillRandom (array_a, SIMDRegister<type>::SIMDNumElements, random);
-            SIMDRegister_test_internal::fillRandom (array_b, SIMDRegister<type>::SIMDNumElements, random);
-            SIMDRegister_test_internal::fillRandom (array_c, SIMDRegister<type>::SIMDNumElements, random);
-            SIMDRegister_test_internal::fillRandom (array_d, SIMDRegister<type>::SIMDNumElements, random);
+            SIMDRegister_test_internal::VecFiller<type>::fill (array_a, SIMDRegister<type>::SIMDNumElements, random);
+            SIMDRegister_test_internal::VecFiller<type>::fill (array_b, SIMDRegister<type>::SIMDNumElements, random);
+            SIMDRegister_test_internal::VecFiller<type>::fill (array_c, SIMDRegister<type>::SIMDNumElements, random);
+            SIMDRegister_test_internal::VecFiller<type>::fill (array_d, SIMDRegister<type>::SIMDNumElements, random);
 
             // check
             for (size_t i = 0; i < SIMDRegister<type>::SIMDNumElements; ++i)
@@ -607,7 +687,10 @@ public:
                     array_max[j] = (array_a[j] > array_b[j]) ? array_a[j] : array_b[j];
                 }
 
-                SIMDRegister<type> a, b, vMin, vMax;
+                SIMDRegister<type> a (static_cast<type> (0));
+                SIMDRegister<type> b (static_cast<type> (0));
+                SIMDRegister<type> vMin (static_cast<type> (0));
+                SIMDRegister<type> vMax (static_cast<type> (0));
 
                 copy (a, array_a);
                 copy (b, array_b);
@@ -638,7 +721,7 @@ public:
             type array [SIMDRegister<type>::SIMDNumElements];
             type sumCheck = 0;
 
-            SIMDRegister_test_internal::fillRandom (array, SIMDRegister<type>::SIMDNumElements, random);
+            SIMDRegister_test_internal::VecFiller<type>::fill (array, SIMDRegister<type>::SIMDNumElements, random);
 
             for (size_t j = 0; j < SIMDRegister<type>::SIMDNumElements; ++j)
             {
@@ -652,6 +735,43 @@ public:
         }
     };
 
+    struct CheckBoolEquals
+    {
+        template <typename type>
+        static void run (UnitTest& u, Random& random)
+        {
+            bool is_signed = std::is_signed<type>::value;
+            type array [SIMDRegister<type>::SIMDNumElements];
+
+            auto value = is_signed ? static_cast<type> ((random.nextFloat() * 16.0) - 8.0)
+                                   : static_cast<type> (random.nextFloat() * 8.0);
+
+            std::fill (array, array + SIMDRegister<type>::SIMDNumElements, value);
+            SIMDRegister<type> a, b;
+            copy (a, array);
+
+            u.expect (a == value);
+            u.expect (! (a != value));
+            value += 1;
+
+            u.expect (a != value);
+            u.expect (! (a == value));
+
+            SIMDRegister_test_internal::VecFiller<type>::fill (array, SIMDRegister<type>::SIMDNumElements, random);
+            copy (a, array);
+            copy (b, array);
+
+            u.expect (a == b);
+            u.expect (! (a != b));
+
+            SIMDRegister_test_internal::VecFiller<type>::fill (array, SIMDRegister<type>::SIMDNumElements, random);
+            copy (b, array);
+
+            u.expect (a != b);
+            u.expect (! (a == b));
+        }
+    };
+
     //==============================================================================
     template <class TheTest>
     void runTestForAllTypes (const char* unitTestName)
@@ -708,6 +828,7 @@ public:
         runTestForAllTypes<BitOperatorTests<BitXOR>> ("BitXOROperators");
 
         runTestNonComplex<CheckComparisonOps> ("CheckComparisons");
+        runTestNonComplex<CheckBoolEquals> ("CheckBoolEquals");
         runTestNonComplex<CheckMinMax> ("CheckMinMax");
 
         runTestForAllTypes<CheckMultiplyAdd> ("CheckMultiplyAdd");
