@@ -92,8 +92,8 @@ struct FFTFallback  : public FFT::Instance
 
     FFTFallback (int order)
     {
-        configForward = new FFTConfig (1 << order, false);
-        configInverse = new FFTConfig (1 << order, true);
+        configForward.reset (new FFTConfig (1 << order, false));
+        configInverse.reset (new FFTConfig (1 << order, true));
 
         size = 1 << order;
     }
@@ -166,10 +166,7 @@ struct FFTFallback  : public FFT::Instance
     void performRealOnlyForwardTransform (Complex<float>* scratch, float* d) const noexcept
     {
         for (int i = 0; i < size; ++i)
-        {
-            scratch[i].real (d[i]);
-            scratch[i].imag (0);
-        }
+            scratch[i] = { d[i], 0 };
 
         perform (scratch, reinterpret_cast<Complex<float>*> (d), false);
     }
@@ -204,8 +201,8 @@ struct FFTFallback  : public FFT::Instance
                 {
                     auto phase = i * inverseFactor;
 
-                    twiddleTable[i].real ((float) std::cos (phase));
-                    twiddleTable[i].imag ((float) std::sin (phase));
+                    twiddleTable[i] = { (float) std::cos (phase),
+                                        (float) std::sin (phase) };
                 }
             }
             else
@@ -214,16 +211,16 @@ struct FFTFallback  : public FFT::Instance
                 {
                     auto phase = i * inverseFactor;
 
-                    twiddleTable[i].real ((float) std::cos (phase));
-                    twiddleTable[i].imag ((float) std::sin (phase));
+                    twiddleTable[i] = { (float) std::cos (phase),
+                                        (float) std::sin (phase) };
                 }
 
                 for (int i = fftSize / 4; i < fftSize / 2; ++i)
                 {
-                    auto index = i - fftSize / 4;
+                    auto other = twiddleTable[i - fftSize / 4];
 
-                    twiddleTable[i].real (inverse ? -twiddleTable[index].imag() : twiddleTable[index].imag());
-                    twiddleTable[i].imag (inverse ? twiddleTable[index].real() : -twiddleTable[index].real());
+                    twiddleTable[i] = { inverse ? -other.imag() :  other.imag(),
+                                        inverse ?  other.real() : -other.real() };
                 }
 
                 twiddleTable[fftSize / 2].real (-1.0f);
@@ -395,17 +392,19 @@ struct FFTFallback  : public FFT::Instance
 
                 if (inverse)
                 {
-                    data[length].real (s5.real() - s4.imag());
-                    data[length].imag (s5.imag() + s4.real());
-                    data[lengthX3].real (s5.real() + s4.imag());
-                    data[lengthX3].imag (s5.imag() - s4.real());
+                    data[length] = { s5.real() - s4.imag(),
+                                     s5.imag() + s4.real() };
+
+                    data[lengthX3] = { s5.real() + s4.imag(),
+                                       s5.imag() - s4.real() };
                 }
                 else
                 {
-                    data[length].real (s5.real() + s4.imag());
-                    data[length].imag (s5.imag() - s4.real());
-                    data[lengthX3].real (s5.real() - s4.imag());
-                    data[lengthX3].imag (s5.imag() + s4.real());
+                    data[length] = { s5.real() + s4.imag(),
+                                     s5.imag() - s4.real() };
+
+                    data[lengthX3] = { s5.real() - s4.imag(),
+                                       s5.imag() + s4.real() };
                 }
 
                 ++data;
@@ -417,7 +416,7 @@ struct FFTFallback  : public FFT::Instance
 
     //==============================================================================
     SpinLock processLock;
-    ScopedPointer<FFTConfig> configForward, configInverse;
+    std::unique_ptr<FFTConfig> configForward, configInverse;
     int size;
 };
 
@@ -438,7 +437,7 @@ struct AppleFFT  : public FFT::Instance
     AppleFFT (int orderToUse)
         : order (static_cast<vDSP_Length> (orderToUse)),
           fftSetup (vDSP_create_fftsetup (order, 2)),
-          forwardNormalisation (.5f),
+          forwardNormalisation (0.5f),
           inverseNormalisation (1.0f / static_cast<float> (1 << order))
     {}
 
