@@ -43,6 +43,8 @@ typedef void* (MessageCallbackFunction) (void* userData);
     This class is in charge of the application's event-dispatch loop.
 
     @see Message, CallbackMessage, MessageManagerLock, JUCEApplication, JUCEApplicationBase
+
+    @tags{Events}
 */
 class JUCE_API  MessageManager  final
 {
@@ -180,7 +182,7 @@ public:
         virtual void messageCallback() = 0;
         bool post();
 
-        typedef ReferenceCountedObjectPtr<MessageBase> Ptr;
+        using Ptr = ReferenceCountedObjectPtr<MessageBase>;
 
         JUCE_DECLARE_NON_COPYABLE (MessageBase)
     };
@@ -317,7 +319,7 @@ private:
     friend class QuitMessage;
     friend class MessageManagerLock;
 
-    ScopedPointer<ActionBroadcaster> broadcaster;
+    std::unique_ptr<ActionBroadcaster> broadcaster;
     Atomic<int> quitMessagePosted { 0 }, quitMessageReceived { 0 };
     Thread::ThreadID messageThreadId;
     Atomic<Thread::ThreadID> threadWithLock;
@@ -376,6 +378,8 @@ private:
     you'll get an (occasional) deadlock..
 
     @see MessageManager, MessageManager::currentThreadHasLockedMessageManager
+
+    @tags{Events}
 */
 class JUCE_API MessageManagerLock      : private Thread::Listener
 {
