@@ -35,6 +35,8 @@ namespace juce
     a brush type. It can either be a solid colour, a gradient, or a tiled image.
 
     @see Graphics::setFillType, DrawablePath::setFill
+
+    @tags{Graphics}
 */
 class JUCE_API  FillType  final
 {
@@ -133,7 +135,7 @@ public:
         If a gradient is active, the overall opacity with which it should be applied
         is indicated by the alpha channel of the colour variable.
     */
-    ScopedPointer<ColourGradient> gradient;
+    std::unique_ptr<ColourGradient> gradient;
 
     /** The image that should be used for tiling.
         If an image fill is active, the overall opacity with which it should be applied
