@@ -35,7 +35,7 @@
 
   ID:               juce_gui_basics
   vendor:           juce
-  version:          5.2.1
+  version:          5.3.2
   name:             JUCE GUI core classes
   description:      Basic user-interface components and related classes.
   website:          http://www.juce.com/juce
@@ -149,12 +149,10 @@ namespace juce
     class ApplicationCommandManagerListener;
     class DrawableButton;
 
-   #if JUCE_COMPILER_SUPPORTS_INITIALIZER_LISTS
     class FlexBox;
     #if JUCE_HAS_CONSTEXPR
      class Grid;
     #endif
-   #endif
 }
 
 #include "mouse/juce_MouseCursor.h"
@@ -280,6 +278,7 @@ namespace juce
 #include "properties/juce_PropertyPanel.h"
 #include "properties/juce_SliderPropertyComponent.h"
 #include "properties/juce_TextPropertyComponent.h"
+#include "properties/juce_MultiChoicePropertyComponent.h"
 #include "application/juce_Application.h"
 #include "misc/juce_BubbleComponent.h"
 #include "lookandfeel/juce_LookAndFeel.h"
@@ -293,13 +292,10 @@ namespace juce
  #include "native/juce_linux_X11.h"
 #endif
 
-// these classes are C++11-only
-#if JUCE_COMPILER_SUPPORTS_INITIALIZER_LISTS
- #include "layout/juce_FlexItem.h"
- #include "layout/juce_FlexBox.h"
+#include "layout/juce_FlexItem.h"
+#include "layout/juce_FlexBox.h"
 
- #if JUCE_HAS_CONSTEXPR
-  #include "layout/juce_GridItem.h"
-  #include "layout/juce_Grid.h"
- #endif
+#if JUCE_HAS_CONSTEXPR
+ #include "layout/juce_GridItem.h"
+ #include "layout/juce_Grid.h"
 #endif
