@@ -2,26 +2,31 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2015 - ROLI Ltd.
+   Copyright (c) 2017 - ROLI Ltd.
 
-   Permission is granted to use this software under the terms of either:
-   a) the GPL v2 (or any later version)
-   b) the Affero GPL v3
+   JUCE is an open source library subject to commercial or open-source
+   licensing.
 
-   Details of these licenses can be found at: www.gnu.org/licenses
+   By using JUCE, you agree to the terms of both the JUCE 5 End-User License
+   Agreement and JUCE 5 Privacy Policy (both updated and effective as of the
+   27th April 2017).
 
-   JUCE is distributed in the hope that it will be useful, but WITHOUT ANY
-   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-   A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+   End User License Agreement: www.juce.com/juce-5-licence
+   Privacy Policy: www.juce.com/juce-5-privacy-policy
 
-   ------------------------------------------------------------------------------
+   Or: You may also use this code under the terms of the GPL v3 (see
+   www.gnu.org/licenses).
 
-   To release a closed-source product which uses JUCE, commercial licenses are
-   available: visit www.juce.com for more information.
+   JUCE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL WARRANTIES, WHETHER
+   EXPRESSED OR IMPLIED, INCLUDING MERCHANTABILITY AND FITNESS FOR PURPOSE, ARE
+   DISCLAIMED.
 
   ==============================================================================
 */
 
+namespace juce
+{
+
 namespace ComponentBuilderHelpers
 {
     static String getStateId (const ValueTree& state)
@@ -50,9 +55,9 @@ namespace ComponentBuilderHelpers
         if (c.getComponentID() == compId)
             return &c;
 
-        for (int i = c.getNumChildComponents(); --i >= 0;)
-            if (Component* const child = findComponentWithID (*c.getChildComponent (i), compId))
-                return child;
+        for (auto* child : c.getChildren())
+            if (auto* found = findComponentWithID (*child, compId))
+                return found;
 
         return nullptr;
     }
@@ -109,7 +114,7 @@ ComponentBuilder::~ComponentBuilder()
    #if JUCE_DEBUG
     // Don't delete the managed component!! The builder owns that component, and will delete
     // it automatically when it gets deleted.
-    jassert (componentRef.get() == static_cast<Component*> (component));
+    jassert (componentRef.get() == component.get());
    #endif
 }
 
@@ -117,14 +122,14 @@ Component* ComponentBuilder::getManagedComponent()
 {
     if (component == nullptr)
     {
-        component = createComponent();
+        component.reset (createComponent());
 
        #if JUCE_DEBUG
-        componentRef = component;
+        componentRef = component.get();
        #endif
     }
 
-    return component;
+    return component.get();
 }
 
 Component* ComponentBuilder::createComponent()
@@ -177,7 +182,6 @@ ComponentBuilder::TypeHandler* ComponentBuilder::getHandler (const int index) co
 
 void ComponentBuilder::registerStandardComponentTypes()
 {
-    Drawable::registerDrawableTypeHandlers (*this);
 }
 
 void ComponentBuilder::setImageProvider (ImageProvider* newImageProvider) noexcept
@@ -236,7 +240,7 @@ void ComponentBuilder::updateChildComponents (Component& parent, const ValueTree
 {
     using namespace ComponentBuilderHelpers;
 
-    const int numExistingChildComps = parent.getNumChildComponents();
+    auto numExistingChildComps = parent.getNumChildComponents();
 
     Array<Component*> componentsInOrder;
     componentsInOrder.ensureStorageAllocated (numExistingChildComps);
@@ -248,15 +252,16 @@ void ComponentBuilder::updateChildComponents (Component& parent, const ValueTree
         for (int i = 0; i < numExistingChildComps; ++i)
             existingComponents.add (parent.getChildComponent (i));
 
-        const int newNumChildren = children.getNumChildren();
+        auto newNumChildren = children.getNumChildren();
+
         for (int i = 0; i < newNumChildren; ++i)
         {
-            const ValueTree childState (children.getChild (i));
-            Component* c = removeComponentWithID (existingComponents, getStateId (childState));
+            auto childState = children.getChild (i);
+            auto* c = removeComponentWithID (existingComponents, getStateId (childState));
 
             if (c == nullptr)
             {
-                if (TypeHandler* const type = getHandlerForState (childState))
+                if (auto* type = getHandlerForState (childState))
                     c = ComponentBuilderHelpers::createNewComponent (*type, childState, &parent);
                 else
                     jassertfalse;
@@ -278,3 +283,5 @@ void ComponentBuilder::updateChildComponents (Component& parent, const ValueTree
             componentsInOrder.getUnchecked(i)->toBehind (componentsInOrder.getUnchecked (i + 1));
     }
 }
+
+} // namespace juce
