@@ -313,8 +313,12 @@ struct Grid::PlacementHelpers
             strings.add (juce::StringArray::fromTokens (areaString, false));
 
         if (strings.size() > 0)
+        {
             for (auto s : strings)
+            {
                 jassert (s.size() == strings[0].size()); // all rows must have the same number of columns
+            }
+        }
 
         return strings;
     }
@@ -1017,7 +1021,7 @@ void Grid::performLayout (juce::Rectangle<int> targetArea)
                                 + targetArea.toFloat().getPosition();
 
         if (auto* c = item->associatedComponent)
-            c->setBounds (item->currentBounds.toNearestInt());
+            c->setBounds (item->currentBounds.toNearestIntEdges());
     }
 }
 
