@@ -33,6 +33,8 @@ namespace juce
 
     @see MouseListener, Component::mouseMove, Component::mouseEnter, Component::mouseExit,
          Component::mouseDown, Component::mouseUp, Component::mouseDrag
+
+    @tags{GUI}
 */
 class JUCE_API  MouseEvent  final
 {
@@ -234,8 +236,8 @@ public:
 
         This is only meaningful if called in either a mouseUp() or mouseDrag() method.
 
-        It will return true if the user has dragged the mouse more than a few pixels
-        from the place where the mouse-down occurred.
+        It will return true if the user has dragged the mouse more than a few pixels from the place
+        where the mouse-down occurred or the mouse has been held down for a significant amount of time.
 
         Once they have dragged it far enough for this method to return true, it will continue
         to return true until the mouse-up, even if they move the mouse back to the same
@@ -377,6 +379,8 @@ private:
     Contains status information about a mouse wheel event.
 
     @see MouseListener, MouseEvent
+
+    @tags{GUI}
 */
 struct MouseWheelDetails  final
 {
@@ -417,6 +421,8 @@ struct MouseWheelDetails  final
     Contains status information about a pen event.
 
     @see MouseListener, MouseEvent
+
+    @tags{GUI}
 */
 struct PenDetails  final
 {
