@@ -407,7 +407,7 @@ void ComboBox::lookAndFeelChanged()
     repaint();
 
     {
-        ScopedPointer<Label> newLabel (getLookAndFeel().createComboBoxTextBox (*this));
+        std::unique_ptr<Label> newLabel (getLookAndFeel().createComboBoxTextBox (*this));
         jassert (newLabel != nullptr);
 
         if (label != nullptr)
