@@ -103,8 +103,6 @@ void ComponentPeer::handleMagnifyGesture (MouseInputSource::InputSourceType type
 //==============================================================================
 void ComponentPeer::handlePaint (LowLevelGraphicsContext& contextToPaintTo)
 {
-    ModifierKeys::updateCurrentModifiers();
-
     Graphics g (contextToPaintTo);
 
     if (component.isTransformed())
@@ -173,10 +171,8 @@ Component* ComponentPeer::getTargetForKeyPress()
 
 bool ComponentPeer::handleKeyPress (const int keyCode, const juce_wchar textCharacter)
 {
-    ModifierKeys::updateCurrentModifiers();
-
     return handleKeyPress (KeyPress (keyCode,
-                                     ModifierKeys::getCurrentModifiers().withoutMouseButtons(),
+                                     ModifierKeys::currentModifiers.withoutMouseButtons(),
                                      textCharacter));
 }
 
@@ -228,7 +224,6 @@ bool ComponentPeer::handleKeyPress (const KeyPress& keyInfo)
 
 bool ComponentPeer::handleKeyUpOrDown (const bool isKeyDown)
 {
-    ModifierKeys::updateCurrentModifiers();
     bool keyWasUsed = false;
 
     for (auto* target = getTargetForKeyPress(); target != nullptr; target = target->getParentComponent())
@@ -259,8 +254,6 @@ bool ComponentPeer::handleKeyUpOrDown (const bool isKeyDown)
 
 void ComponentPeer::handleModifierKeysChange()
 {
-    ModifierKeys::updateCurrentModifiers();
-
     auto* target = Desktop::getInstance().getMainMouseSource().getComponentUnderMouse();
 
     if (target == nullptr)
@@ -289,7 +282,6 @@ void ComponentPeer::dismissPendingTextInput() {}
 //==============================================================================
 void ComponentPeer::handleBroughtToFront()
 {
-    ModifierKeys::updateCurrentModifiers();
     component.internalBroughtToFront();
 }
 
@@ -300,8 +292,6 @@ void ComponentPeer::setConstrainer (ComponentBoundsConstrainer* const newConstra
 
 void ComponentPeer::handleMovedOrResized()
 {
-    ModifierKeys::updateCurrentModifiers();
-
     const bool nowMinimised = isMinimised();
 
     if (component.flags.hasHeavyweightPeerFlag && ! nowMinimised)
@@ -341,8 +331,6 @@ void ComponentPeer::handleMovedOrResized()
 
 void ComponentPeer::handleFocusGain()
 {
-    ModifierKeys::updateCurrentModifiers();
-
     if (component.isParentOf (lastFocusedComponent)
           && lastFocusedComponent->isShowing()
           && lastFocusedComponent->getWantsKeyboardFocus())
@@ -362,8 +350,6 @@ void ComponentPeer::handleFocusGain()
 
 void ComponentPeer::handleFocusLoss()
 {
-    ModifierKeys::updateCurrentModifiers();
-
     if (component.hasKeyboardFocus (true))
     {
         lastFocusedComponent = Component::currentlyFocusedComponent;
@@ -386,8 +372,6 @@ Component* ComponentPeer::getLastFocusedSubcomponent() const noexcept
 
 void ComponentPeer::handleScreenSizeChange()
 {
-    ModifierKeys::updateCurrentModifiers();
-
     component.parentSizeChanged();
     handleMovedOrResized();
 }
@@ -453,8 +437,6 @@ namespace DragHelpers
 
 bool ComponentPeer::handleDragMove (const ComponentPeer::DragInfo& info)
 {
-    ModifierKeys::updateCurrentModifiers();
-
     auto* compUnderMouse = component.getComponentAt (info.position);
     auto* lastTarget = dragAndDropTargetComponent.get();
     Component* newTarget = nullptr;
@@ -562,7 +544,6 @@ bool ComponentPeer::handleDragDrop (const ComponentPeer::DragInfo& info)
 //==============================================================================
 void ComponentPeer::handleUserClosingWindow()
 {
-    ModifierKeys::updateCurrentModifiers();
     component.userTriedToCloseWindow();
 }
 
@@ -579,4 +560,16 @@ void ComponentPeer::setRepresentedFile (const File&)
 int ComponentPeer::getCurrentRenderingEngine() const            { return 0; }
 void ComponentPeer::setCurrentRenderingEngine (int index)       { jassert (index == 0); ignoreUnused (index); }
 
+//==============================================================================
+std::function<ModifierKeys()> ComponentPeer::getNativeRealtimeModifiers = nullptr;
+
+ModifierKeys ComponentPeer::getCurrentModifiersRealtime() noexcept
+{
+    if (getNativeRealtimeModifiers != nullptr)
+        return getNativeRealtimeModifiers();
+
+    return ModifierKeys::currentModifiers;
+}
+
+
 } // namespace juce
