@@ -38,6 +38,8 @@ namespace juce
     User-code should very rarely need to have any involvement with this class.
 
     @see Component::createNewPeer
+
+    @tags{GUI}
 */
 class JUCE_API  ComponentPeer
 {
@@ -323,6 +325,7 @@ public:
 
     void handleUserClosingWindow();
 
+    /** Structure to describe drag and drop information */
     struct DragInfo
     {
         StringArray files;
@@ -361,12 +364,26 @@ public:
     virtual int getCurrentRenderingEngine() const;
     virtual void setCurrentRenderingEngine (int index);
 
+    //==============================================================================
+    /** On desktop platforms this method will check all the mouse and key states and return
+        a ModifierKeys object representing them.
+
+        This isn't recommended and is only needed in special circumstances for up-to-date
+        modifier information at times when the app's event loop isn't running normally.
+
+        Another reason to avoid this method is that it's not stateless and calling it may
+        update the ModifierKeys::currentModifiers object, which could cause subtle changes
+        in the behaviour of some components.
+    */
+    static ModifierKeys getCurrentModifiersRealtime() noexcept;
+
 protected:
     //==============================================================================
     Component& component;
     const int styleFlags;
     Rectangle<int> lastNonFullscreenBounds;
     ComponentBoundsConstrainer* constrainer = nullptr;
+    static std::function<ModifierKeys()> getNativeRealtimeModifiers;
 
 private:
     //==============================================================================
