@@ -27,10 +27,6 @@
 namespace juce
 {
 
-#if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
-template <> struct ContainerDeletePolicy<NSObject<UIApplicationDelegate, UNUserNotificationCenterDelegate>> { static void destroy (NSObject* o) { [o release]; } };
-#endif
-
 namespace PushNotificationsDelegateDetails
 {
     //==============================================================================
@@ -58,7 +54,7 @@ namespace PushNotificationsDelegateDetails
         }
         else
         {
-          #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
+           #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
             if (a.style == Action::text)
             {
                 return [UNTextInputNotificationAction actionWithIdentifier: juceStringToNS (a.identifier)
@@ -71,9 +67,9 @@ namespace PushNotificationsDelegateDetails
             return [UNNotificationAction actionWithIdentifier: juceStringToNS (a.identifier)
                                                         title: juceStringToNS (a.title)
                                                       options: NSUInteger (a.destructive << 1 | (! a.triggerInBackground) << 2)];
-          #else
+           #else
             return nullptr;
-          #endif
+           #endif
         }
     }
 
@@ -101,7 +97,7 @@ namespace PushNotificationsDelegateDetails
         }
         else
         {
-          #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
+           #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
             auto* actions = [NSMutableArray arrayWithCapacity: (NSUInteger) c.actions.size()];
 
             for (const auto& a : c.actions)
@@ -114,9 +110,9 @@ namespace PushNotificationsDelegateDetails
                                                           actions: actions
                                                 intentIdentifiers: @[]
                                                           options: c.sendDismissAction ? UNNotificationCategoryOptionCustomDismissAction : 0];
-          #else
+           #else
             return nullptr;
-          #endif
+           #endif
         }
     }
 
@@ -144,7 +140,7 @@ namespace PushNotificationsDelegateDetails
         return notification;
     }
 
-  #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
+   #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
     UNNotificationRequest* juceNotificationToUNNotificationRequest (const PushNotifications::Notification& n)
     {
         // content
@@ -188,7 +184,7 @@ namespace PushNotificationsDelegateDetails
 
         return request;
     }
-  #endif
+   #endif
 
     String getUserResponseFromNSDictionary (NSDictionary* dictionary)
     {
@@ -237,7 +233,7 @@ namespace PushNotificationsDelegateDetails
     }
 
     //==============================================================================
-  #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
+   #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
     double getIntervalSecFromUNNotificationTrigger (UNNotificationTrigger* t)
     {
         if (t != nil)
@@ -292,7 +288,7 @@ namespace PushNotificationsDelegateDetails
     {
         return unNotificationRequestToJuceNotification (n.request);
     }
-  #endif
+   #endif
 
     PushNotifications::Notification uiLocalNotificationToJuceNotification (UILocalNotification* n)
     {
@@ -343,7 +339,7 @@ namespace PushNotificationsDelegateDetails
         return category;
     }
 
-  #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
+   #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
     Action unNotificationActionToAction (UNNotificationAction* a)
     {
         Action action;
@@ -381,7 +377,7 @@ namespace PushNotificationsDelegateDetails
 
         return category;
     }
-  #endif
+   #endif
 
     PushNotifications::Notification nsDictionaryToJuceNotification (NSDictionary* dictionary)
     {
@@ -421,14 +417,14 @@ struct PushNotificationsDelegate
 {
     PushNotificationsDelegate() : delegate ([getClass().createInstance() init])
     {
-        Class::setThis (delegate, this);
+        Class::setThis (delegate.get(), this);
 
         id<UIApplicationDelegate> appDelegate = [[UIApplication sharedApplication] delegate];
 
         SEL selector = NSSelectorFromString (@"setPushNotificationsDelegateToUse:");
 
         if ([appDelegate respondsToSelector: selector])
-            [appDelegate performSelector: selector withObject: delegate];
+            [appDelegate performSelector: selector withObject: delegate.get()];
     }
 
     virtual ~PushNotificationsDelegate() {}
@@ -460,32 +456,32 @@ struct PushNotificationsDelegate
                                                                                 NSDictionary* responseInfo,
                                                                                 void (^completionHandler)()) = 0;
 
-  #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
+   #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
     virtual void willPresentNotificationWithCompletionHandler (UNNotification* notification,
                                                                void (^completionHandler)(UNNotificationPresentationOptions options)) = 0;
 
     virtual void didReceiveNotificationResponseWithCompletionHandler (UNNotificationResponse* response,
                                                                       void (^completionHandler)()) = 0;
-  #endif
+   #endif
 
 protected:
-  #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
-    ScopedPointer<NSObject<UIApplicationDelegate, UNUserNotificationCenterDelegate>> delegate;
-  #else
-    ScopedPointer<NSObject<UIApplicationDelegate>> delegate;
-  #endif
+   #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
+    std::unique_ptr<NSObject<UIApplicationDelegate, UNUserNotificationCenterDelegate>, NSObjectDeleter> delegate;
+   #else
+    std::unique_ptr<NSObject<UIApplicationDelegate>, NSObjectDeleter> delegate;
+   #endif
 
 private:
     //==============================================================================
-  #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
+   #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
     struct Class    : public ObjCClass<NSObject<UIApplicationDelegate, UNUserNotificationCenterDelegate>>
     {
         Class() : ObjCClass<NSObject<UIApplicationDelegate, UNUserNotificationCenterDelegate>> ("JucePushNotificationsDelegate_")
-  #else
+   #else
     struct Class    : public ObjCClass<NSObject<UIApplicationDelegate>>
     {
         Class() : ObjCClass<NSObject<UIApplicationDelegate>> ("JucePushNotificationsDelegate_")
-  #endif
+   #endif
         {
             addIvar<PushNotificationsDelegate*> ("self");
 
@@ -499,10 +495,10 @@ private:
             addMethod (@selector (application:handleActionWithIdentifier:forLocalNotification:completionHandler:),                   handleActionForLocalNotificationCompletionHandler,              "v@:@@@@");
             addMethod (@selector (application:handleActionWithIdentifier:forLocalNotification:withResponseInfo:completionHandler:),  handleActionForLocalNotificationWithResponseCompletionHandler,  "v@:@@@@@");
 
-          #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
+           #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
             addMethod (@selector (userNotificationCenter:willPresentNotification:withCompletionHandler:),                            willPresentNotificationWithCompletionHandler,                   "v@:@@@");
             addMethod (@selector (userNotificationCenter:didReceiveNotificationResponse:withCompletionHandler:),                     didReceiveNotificationResponseWithCompletionHandler,            "v@:@@@");
-          #endif
+           #endif
 
             registerClass();
         }
@@ -547,7 +543,7 @@ private:
                                                                                    NSDictionary* responseInfo,
                                                                                    void (^completionHandler)())                                 { getThis (self). handleActionForLocalNotificationWithResponseCompletionHandler (actionIdentifier, notification, responseInfo, completionHandler); }
 
-      #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
+       #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
         static void willPresentNotificationWithCompletionHandler        (id self, SEL, UNUserNotificationCenter*,
                                                                          UNNotification* notification,
                                                                          void (^completionHandler)(UNNotificationPresentationOptions options))  { getThis (self).willPresentNotificationWithCompletionHandler (notification, completionHandler); }
@@ -555,7 +551,7 @@ private:
         static void didReceiveNotificationResponseWithCompletionHandler (id self, SEL, UNUserNotificationCenter*,
                                                                          UNNotificationResponse* response,
                                                                          void (^completionHandler)())                                           { getThis (self).didReceiveNotificationResponseWithCompletionHandler (response, completionHandler); }
-      #endif
+       #endif
     };
 
     //==============================================================================
@@ -923,7 +919,7 @@ struct PushNotifications::Pimpl : private PushNotificationsDelegate
         completionHandler();
     }
 
-  #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
+   #if defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
     void willPresentNotificationWithCompletionHandler (UNNotification* notification,
                                                        void (^completionHandler)(UNNotificationPresentationOptions options)) override
     {
@@ -961,7 +957,7 @@ struct PushNotifications::Pimpl : private PushNotificationsDelegate
         owner.listeners.call ([&] (Listener& l) { l.handleNotificationAction (! remote, n, actionString, responseString); });
         completionHandler();
     }
-  #endif
+   #endif
 
     void subscribeToTopic (const String& topic)     { ignoreUnused (topic); }
     void unsubscribeFromTopic (const String& topic) { ignoreUnused (topic); }
