@@ -449,17 +449,18 @@ public:
 
         unsigned long windowHandle;
         ssize_t actual = read (inChannel, &windowHandle, sizeof (windowHandle));
+
         if (actual != sizeof (windowHandle))
         {
             killChild();
             return;
         }
 
-        receiver = new CommandReceiver (this, inChannel);
+        receiver.reset (new CommandReceiver (this, inChannel));
         startThread();
 
-        xembed = new XEmbedComponent (windowHandle);
-        owner.addAndMakeVisible (xembed);
+        xembed.reset (new XEmbedComponent (windowHandle));
+        owner.addAndMakeVisible (xembed.get());
     }
 
     void quit()
@@ -696,10 +697,10 @@ private:
 
 private:
     WebBrowserComponent& owner;
-    ScopedPointer<CommandReceiver> receiver;
+    std::unique_ptr<CommandReceiver> receiver;
     int childProcess = 0, inChannel = 0, outChannel = 0;
     int threadControl[2];
-    ScopedPointer<XEmbedComponent> xembed;
+    std::unique_ptr<XEmbedComponent> xembed;
     WaitableEvent threadBlocker;
 };
 
