@@ -76,7 +76,7 @@ public:
     class SharedKeyWindow : public ReferenceCountedObject
     {
     public:
-        typedef ReferenceCountedObjectPtr<SharedKeyWindow> Ptr;
+        using Ptr = ReferenceCountedObjectPtr<SharedKeyWindow>;
 
         //==============================================================================
         Window getHandle()    { return keyProxy; }
